# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: orderer/configuration.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1borderer/configuration.proto\x12\x07orderer\"\x8e\x01\n\rConsensusType\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x10\n\x08metadata\x18\x02 \x01(\x0c\x12+\n\x05state\x18\x03 \x01(\x0e\x32\x1c.orderer.ConsensusType.State\"0\n\x05State\x12\x10\n\x0cSTATE_NORMAL\x10\x00\x12\x15\n\x11STATE_MAINTENANCE\x10\x01\"_\n\tBatchSize\x12\x19\n\x11max_message_count\x18\x01 \x01(\r\x12\x1a\n\x12\x61\x62solute_max_bytes\x18\x02 \x01(\r\x12\x1b\n\x13preferred_max_bytes\x18\x03 \x01(\r\"\x1f\n\x0c\x42\x61tchTimeout\x12\x0f\n\x07timeout\x18\x01 \x01(\t\"\x1f\n\x0cKafkaBrokers\x12\x0f\n\x07\x62rokers\x18\x01 \x03(\t\"(\n\x13\x43hannelRestrictions\x12\x11\n\tmax_count\x18\x01 \x01(\x04\x42X\n%org.hyperledger.fabric.protos.ordererZ/github.com/hyperledger/fabric-protos-go/ordererb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'orderer.configuration_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%org.hyperledger.fabric.protos.ordererZ/github.com/hyperledger/fabric-protos-go/orderer'
  _CONSENSUSTYPE._serialized_start=41
  _CONSENSUSTYPE._serialized_end=183
  _CONSENSUSTYPE_STATE._serialized_start=135
  _CONSENSUSTYPE_STATE._serialized_end=183
  _BATCHSIZE._serialized_start=185
  _BATCHSIZE._serialized_end=280
  _BATCHTIMEOUT._serialized_start=282
  _BATCHTIMEOUT._serialized_end=313
  _KAFKABROKERS._serialized_start=315
  _KAFKABROKERS._serialized_end=346
  _CHANNELRESTRICTIONS._serialized_start=348
  _CHANNELRESTRICTIONS._serialized_end=388
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: peer/lifecycle/lifecycle.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fabric_protos_python.peer import collection_pb2 as peer_dot_collection__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1epeer/lifecycle/lifecycle.proto\x12\tlifecycle\x1a\x15peer/collection.proto\"9\n\x14InstallChaincodeArgs\x12!\n\x19\x63haincode_install_package\x18\x01 \x01(\x0c\";\n\x16InstallChaincodeResult\x12\x12\n\npackage_id\x18\x01 \x01(\t\x12\r\n\x05label\x18\x02 \x01(\t\"1\n\x1bQueryInstalledChaincodeArgs\x12\x12\n\npackage_id\x18\x01 \x01(\t\"\xfa\x02\n\x1dQueryInstalledChaincodeResult\x12\x12\n\npackage_id\x18\x01 \x01(\t\x12\r\n\x05label\x18\x02 \x01(\t\x12L\n\nreferences\x18\x03 \x03(\x0b\x32\x38.lifecycle.QueryInstalledChaincodeResult.ReferencesEntry\x1a\x66\n\x0fReferencesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x42\n\x05value\x18\x02 \x01(\x0b\x32\x33.lifecycle.QueryInstalledChaincodeResult.References:\x02\x38\x01\x1aT\n\nReferences\x12\x46\n\nchaincodes\x18\x01 \x03(\x0b\x32\x32.lifecycle.QueryInstalledChaincodeResult.Chaincode\x1a*\n\tChaincode\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\"6\n GetInstalledChaincodePackageArgs\x12\x12\n\npackage_id\x18\x01 \x01(\t\"G\n\"GetInstalledChaincodePackageResult\x12!\n\x19\x63haincode_install_package\x18\x01 \x01(\x0c\"\x1e\n\x1cQueryInstalledChaincodesArgs\"\x84\x04\n\x1eQueryInstalledChaincodesResult\x12Z\n\x14installed_chaincodes\x18\x01 \x03(\x0b\x32<.lifecycle.QueryInstalledChaincodesResult.InstalledChaincode\x1a\x82\x02\n\x12InstalledChaincode\x12\x12\n\npackage_id\x18\x01 \x01(\t\x12\r\n\x05label\x18\x02 \x01(\t\x12`\n\nreferences\x18\x03 \x03(\x0b\x32L.lifecycle.QueryInstalledChaincodesResult.InstalledChaincode.ReferencesEntry\x1ag\n\x0fReferencesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x43\n\x05value\x18\x02 \x01(\x0b\x32\x34.lifecycle.QueryInstalledChaincodesResult.References:\x02\x38\x01\x1aU\n\nReferences\x12G\n\nchaincodes\x18\x01 \x03(\x0b\x32\x33.lifecycle.QueryInstalledChaincodesResult.Chaincode\x1a*\n\tChaincode\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\"\xa7\x02\n&ApproveChaincodeDefinitionForMyOrgArgs\x12\x10\n\x08sequence\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\x12\x1a\n\x12\x65ndorsement_plugin\x18\x04 \x01(\t\x12\x19\n\x11validation_plugin\x18\x05 \x01(\t\x12\x1c\n\x14validation_parameter\x18\x06 \x01(\x0c\x12\x34\n\x0b\x63ollections\x18\x07 \x01(\x0b\x32\x1f.protos.CollectionConfigPackage\x12\x15\n\rinit_required\x18\x08 \x01(\x08\x12*\n\x06source\x18\t \x01(\x0b\x32\x1a.lifecycle.ChaincodeSource\"\xbf\x01\n\x0f\x43haincodeSource\x12=\n\x0bunavailable\x18\x01 \x01(\x0b\x32&.lifecycle.ChaincodeSource.UnavailableH\x00\x12\x39\n\rlocal_package\x18\x02 \x01(\x0b\x32 .lifecycle.ChaincodeSource.LocalH\x00\x1a\r\n\x0bUnavailable\x1a\x1b\n\x05Local\x12\x12\n\npackage_id\x18\x01 \x01(\tB\x06\n\x04Type\"*\n(ApproveChaincodeDefinitionForMyOrgResult\"\xf2\x01\n\x1d\x43ommitChaincodeDefinitionArgs\x12\x10\n\x08sequence\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\x12\x1a\n\x12\x65ndorsement_plugin\x18\x04 \x01(\t\x12\x19\n\x11validation_plugin\x18\x05 \x01(\t\x12\x1c\n\x14validation_parameter\x18\x06 \x01(\x0c\x12\x34\n\x0b\x63ollections\x18\x07 \x01(\x0b\x32\x1f.protos.CollectionConfigPackage\x12\x15\n\rinit_required\x18\x08 \x01(\x08\"!\n\x1f\x43ommitChaincodeDefinitionResult\"\xed\x01\n\x18\x43heckCommitReadinessArgs\x12\x10\n\x08sequence\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\x12\x1a\n\x12\x65ndorsement_plugin\x18\x04 \x01(\t\x12\x19\n\x11validation_plugin\x18\x05 \x01(\t\x12\x1c\n\x14validation_parameter\x18\x06 \x01(\x0c\x12\x34\n\x0b\x63ollections\x18\x07 \x01(\x0b\x32\x1f.protos.CollectionConfigPackage\x12\x15\n\rinit_required\x18\x08 \x01(\x08\"\x97\x01\n\x1a\x43heckCommitReadinessResult\x12G\n\tapprovals\x18\x01 \x03(\x0b\x32\x34.lifecycle.CheckCommitReadinessResult.ApprovalsEntry\x1a\x30\n\x0e\x41pprovalsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\"F\n$QueryApprovedChaincodeDefinitionArgs\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08sequence\x18\x02 \x01(\x03\"\x99\x02\n&QueryApprovedChaincodeDefinitionResult\x12\x10\n\x08sequence\x18\x01 \x01(\x03\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x1a\n\x12\x65ndorsement_plugin\x18\x03 \x01(\t\x12\x19\n\x11validation_plugin\x18\x04 \x01(\t\x12\x1c\n\x14validation_parameter\x18\x05 \x01(\x0c\x12\x34\n\x0b\x63ollections\x18\x06 \x01(\x0b\x32\x1f.protos.CollectionConfigPackage\x12\x15\n\rinit_required\x18\x07 \x01(\x08\x12*\n\x06source\x18\x08 \x01(\x0b\x32\x1a.lifecycle.ChaincodeSource\",\n\x1cQueryChaincodeDefinitionArgs\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xe4\x02\n\x1eQueryChaincodeDefinitionResult\x12\x10\n\x08sequence\x18\x01 \x01(\x03\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x1a\n\x12\x65ndorsement_plugin\x18\x03 \x01(\t\x12\x19\n\x11validation_plugin\x18\x04 \x01(\t\x12\x1c\n\x14validation_parameter\x18\x05 \x01(\x0c\x12\x34\n\x0b\x63ollections\x18\x06 \x01(\x0b\x32\x1f.protos.CollectionConfigPackage\x12\x15\n\rinit_required\x18\x07 \x01(\x08\x12K\n\tapprovals\x18\x08 \x03(\x0b\x32\x38.lifecycle.QueryChaincodeDefinitionResult.ApprovalsEntry\x1a\x30\n\x0e\x41pprovalsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\"\x1f\n\x1dQueryChaincodeDefinitionsArgs\"\xeb\x02\n\x1fQueryChaincodeDefinitionsResult\x12]\n\x15\x63haincode_definitions\x18\x01 \x03(\x0b\x32>.lifecycle.QueryChaincodeDefinitionsResult.ChaincodeDefinition\x1a\xe8\x01\n\x13\x43haincodeDefinition\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08sequence\x18\x02 \x01(\x03\x12\x0f\n\x07version\x18\x03 \x01(\t\x12\x1a\n\x12\x65ndorsement_plugin\x18\x04 \x01(\t\x12\x19\n\x11validation_plugin\x18\x05 \x01(\t\x12\x1c\n\x14validation_parameter\x18\x06 \x01(\x0c\x12\x34\n\x0b\x63ollections\x18\x07 \x01(\x0b\x32\x1f.protos.CollectionConfigPackage\x12\x15\n\rinit_required\x18\x08 \x01(\x08\x42\x66\n,org.hyperledger.fabric.protos.peer.lifecycleZ6github.com/hyperledger/fabric-protos-go/peer/lifecycleb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'peer.lifecycle.lifecycle_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n,org.hyperledger.fabric.protos.peer.lifecycleZ6github.com/hyperledger/fabric-protos-go/peer/lifecycle'
  _QUERYINSTALLEDCHAINCODERESULT_REFERENCESENTRY._options = None
  _QUERYINSTALLEDCHAINCODERESULT_REFERENCESENTRY._serialized_options = b'8\001'
  _QUERYINSTALLEDCHAINCODESRESULT_INSTALLEDCHAINCODE_REFERENCESENTRY._options = None
  _QUERYINSTALLEDCHAINCODESRESULT_INSTALLEDCHAINCODE_REFERENCESENTRY._serialized_options = b'8\001'
  _CHECKCOMMITREADINESSRESULT_APPROVALSENTRY._options = None
  _CHECKCOMMITREADINESSRESULT_APPROVALSENTRY._serialized_options = b'8\001'
  _QUERYCHAINCODEDEFINITIONRESULT_APPROVALSENTRY._options = None
  _QUERYCHAINCODEDEFINITIONRESULT_APPROVALSENTRY._serialized_options = b'8\001'
  _INSTALLCHAINCODEARGS._serialized_start=68
  _INSTALLCHAINCODEARGS._serialized_end=125
  _INSTALLCHAINCODERESULT._serialized_start=127
  _INSTALLCHAINCODERESULT._serialized_end=186
  _QUERYINSTALLEDCHAINCODEARGS._serialized_start=188
  _QUERYINSTALLEDCHAINCODEARGS._serialized_end=237
  _QUERYINSTALLEDCHAINCODERESULT._serialized_start=240
  _QUERYINSTALLEDCHAINCODERESULT._serialized_end=618
  _QUERYINSTALLEDCHAINCODERESULT_REFERENCESENTRY._serialized_start=386
  _QUERYINSTALLEDCHAINCODERESULT_REFERENCESENTRY._serialized_end=488
  _QUERYINSTALLEDCHAINCODERESULT_REFERENCES._serialized_start=490
  _QUERYINSTALLEDCHAINCODERESULT_REFERENCES._serialized_end=574
  _QUERYINSTALLEDCHAINCODERESULT_CHAINCODE._serialized_start=576
  _QUERYINSTALLEDCHAINCODERESULT_CHAINCODE._serialized_end=618
  _GETINSTALLEDCHAINCODEPACKAGEARGS._serialized_start=620
  _GETINSTALLEDCHAINCODEPACKAGEARGS._serialized_end=674
  _GETINSTALLEDCHAINCODEPACKAGERESULT._serialized_start=676
  _GETINSTALLEDCHAINCODEPACKAGERESULT._serialized_end=747
  _QUERYINSTALLEDCHAINCODESARGS._serialized_start=749
  _QUERYINSTALLEDCHAINCODESARGS._serialized_end=779
  _QUERYINSTALLEDCHAINCODESRESULT._serialized_start=782
  _QUERYINSTALLEDCHAINCODESRESULT._serialized_end=1298
  _QUERYINSTALLEDCHAINCODESRESULT_INSTALLEDCHAINCODE._serialized_start=909
  _QUERYINSTALLEDCHAINCODESRESULT_INSTALLEDCHAINCODE._serialized_end=1167
  _QUERYINSTALLEDCHAINCODESRESULT_INSTALLEDCHAINCODE_REFERENCESENTRY._serialized_start=1064
  _QUERYINSTALLEDCHAINCODESRESULT_INSTALLEDCHAINCODE_REFERENCESENTRY._serialized_end=1167
  _QUERYINSTALLEDCHAINCODESRESULT_REFERENCES._serialized_start=1169
  _QUERYINSTALLEDCHAINCODESRESULT_REFERENCES._serialized_end=1254
  _QUERYINSTALLEDCHAINCODESRESULT_CHAINCODE._serialized_start=576
  _QUERYINSTALLEDCHAINCODESRESULT_CHAINCODE._serialized_end=618
  _APPROVECHAINCODEDEFINITIONFORMYORGARGS._serialized_start=1301
  _APPROVECHAINCODEDEFINITIONFORMYORGARGS._serialized_end=1596
  _CHAINCODESOURCE._serialized_start=1599
  _CHAINCODESOURCE._serialized_end=1790
  _CHAINCODESOURCE_UNAVAILABLE._serialized_start=1740
  _CHAINCODESOURCE_UNAVAILABLE._serialized_end=1753
  _CHAINCODESOURCE_LOCAL._serialized_start=1755
  _CHAINCODESOURCE_LOCAL._serialized_end=1782
  _APPROVECHAINCODEDEFINITIONFORMYORGRESULT._serialized_start=1792
  _APPROVECHAINCODEDEFINITIONFORMYORGRESULT._serialized_end=1834
  _COMMITCHAINCODEDEFINITIONARGS._serialized_start=1837
  _COMMITCHAINCODEDEFINITIONARGS._serialized_end=2079
  _COMMITCHAINCODEDEFINITIONRESULT._serialized_start=2081
  _COMMITCHAINCODEDEFINITIONRESULT._serialized_end=2114
  _CHECKCOMMITREADINESSARGS._serialized_start=2117
  _CHECKCOMMITREADINESSARGS._serialized_end=2354
  _CHECKCOMMITREADINESSRESULT._serialized_start=2357
  _CHECKCOMMITREADINESSRESULT._serialized_end=2508
  _CHECKCOMMITREADINESSRESULT_APPROVALSENTRY._serialized_start=2460
  _CHECKCOMMITREADINESSRESULT_APPROVALSENTRY._serialized_end=2508
  _QUERYAPPROVEDCHAINCODEDEFINITIONARGS._serialized_start=2510
  _QUERYAPPROVEDCHAINCODEDEFINITIONARGS._serialized_end=2580
  _QUERYAPPROVEDCHAINCODEDEFINITIONRESULT._serialized_start=2583
  _QUERYAPPROVEDCHAINCODEDEFINITIONRESULT._serialized_end=2864
  _QUERYCHAINCODEDEFINITIONARGS._serialized_start=2866
  _QUERYCHAINCODEDEFINITIONARGS._serialized_end=2910
  _QUERYCHAINCODEDEFINITIONRESULT._serialized_start=2913
  _QUERYCHAINCODEDEFINITIONRESULT._serialized_end=3269
  _QUERYCHAINCODEDEFINITIONRESULT_APPROVALSENTRY._serialized_start=2460
  _QUERYCHAINCODEDEFINITIONRESULT_APPROVALSENTRY._serialized_end=2508
  _QUERYCHAINCODEDEFINITIONSARGS._serialized_start=3271
  _QUERYCHAINCODEDEFINITIONSARGS._serialized_end=3302
  _QUERYCHAINCODEDEFINITIONSRESULT._serialized_start=3305
  _QUERYCHAINCODEDEFINITIONSRESULT._serialized_end=3668
  _QUERYCHAINCODEDEFINITIONSRESULT_CHAINCODEDEFINITION._serialized_start=3436
  _QUERYCHAINCODEDEFINITIONSRESULT_CHAINCODEDEFINITION._serialized_end=3668
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: msp/msp_principal.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17msp/msp_principal.proto\x12\x06\x63ommon\"\xc6\x01\n\x0cMSPPrincipal\x12\x45\n\x18principal_classification\x18\x01 \x01(\x0e\x32#.common.MSPPrincipal.Classification\x12\x11\n\tprincipal\x18\x02 \x01(\x0c\"\\\n\x0e\x43lassification\x12\x08\n\x04ROLE\x10\x00\x12\x15\n\x11ORGANIZATION_UNIT\x10\x01\x12\x0c\n\x08IDENTITY\x10\x02\x12\r\n\tANONYMITY\x10\x03\x12\x0c\n\x08\x43OMBINED\x10\x04\"q\n\x10OrganizationUnit\x12\x16\n\x0emsp_identifier\x18\x01 \x01(\t\x12&\n\x1eorganizational_unit_identifier\x18\x02 \x01(\t\x12\x1d\n\x15\x63\x65rtifiers_identifier\x18\x03 \x01(\x0c\"\x95\x01\n\x07MSPRole\x12\x16\n\x0emsp_identifier\x18\x01 \x01(\t\x12)\n\x04role\x18\x02 \x01(\x0e\x32\x1b.common.MSPRole.MSPRoleType\"G\n\x0bMSPRoleType\x12\n\n\x06MEMBER\x10\x00\x12\t\n\x05\x41\x44MIN\x10\x01\x12\n\n\x06\x43LIENT\x10\x02\x12\x08\n\x04PEER\x10\x03\x12\x0b\n\x07ORDERER\x10\x04\"\x9d\x01\n\x14MSPIdentityAnonymity\x12M\n\x0e\x61nonymity_type\x18\x01 \x01(\x0e\x32\x35.common.MSPIdentityAnonymity.MSPIdentityAnonymityType\"6\n\x18MSPIdentityAnonymityType\x12\x0b\n\x07NOMINAL\x10\x00\x12\r\n\tANONYMOUS\x10\x01\"=\n\x11\x43ombinedPrincipal\x12(\n\nprincipals\x18\x01 \x03(\x0b\x32\x14.common.MSPPrincipalBS\n$org.hyperledger.fabric.protos.commonZ+github.com/hyperledger/fabric-protos-go/mspb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'msp.msp_principal_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$org.hyperledger.fabric.protos.commonZ+github.com/hyperledger/fabric-protos-go/msp'
  _MSPPRINCIPAL._serialized_start=36
  _MSPPRINCIPAL._serialized_end=234
  _MSPPRINCIPAL_CLASSIFICATION._serialized_start=142
  _MSPPRINCIPAL_CLASSIFICATION._serialized_end=234
  _ORGANIZATIONUNIT._serialized_start=236
  _ORGANIZATIONUNIT._serialized_end=349
  _MSPROLE._serialized_start=352
  _MSPROLE._serialized_end=501
  _MSPROLE_MSPROLETYPE._serialized_start=430
  _MSPROLE_MSPROLETYPE._serialized_end=501
  _MSPIDENTITYANONYMITY._serialized_start=504
  _MSPIDENTITYANONYMITY._serialized_end=661
  _MSPIDENTITYANONYMITY_MSPIDENTITYANONYMITYTYPE._serialized_start=607
  _MSPIDENTITYANONYMITY_MSPIDENTITYANONYMITYTYPE._serialized_end=661
  _COMBINEDPRINCIPAL._serialized_start=663
  _COMBINEDPRINCIPAL._serialized_end=724
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: peer/chaincode_shim.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fabric_protos_python.peer import chaincode_event_pb2 as peer_dot_chaincode__event__pb2
from fabric_protos_python.peer import proposal_pb2 as peer_dot_proposal__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19peer/chaincode_shim.proto\x12\x06protos\x1a\x1apeer/chaincode_event.proto\x1a\x13peer/proposal.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x91\x05\n\x10\x43haincodeMessage\x12+\n\x04type\x18\x01 \x01(\x0e\x32\x1d.protos.ChaincodeMessage.Type\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07payload\x18\x03 \x01(\x0c\x12\x0c\n\x04txid\x18\x04 \x01(\t\x12(\n\x08proposal\x18\x05 \x01(\x0b\x32\x16.protos.SignedProposal\x12/\n\x0f\x63haincode_event\x18\x06 \x01(\x0b\x32\x16.protos.ChaincodeEvent\x12\x12\n\nchannel_id\x18\x07 \x01(\t\"\x92\x03\n\x04Type\x12\r\n\tUNDEFINED\x10\x00\x12\x0c\n\x08REGISTER\x10\x01\x12\x0e\n\nREGISTERED\x10\x02\x12\x08\n\x04INIT\x10\x03\x12\t\n\x05READY\x10\x04\x12\x0f\n\x0bTRANSACTION\x10\x05\x12\r\n\tCOMPLETED\x10\x06\x12\t\n\x05\x45RROR\x10\x07\x12\r\n\tGET_STATE\x10\x08\x12\r\n\tPUT_STATE\x10\t\x12\r\n\tDEL_STATE\x10\n\x12\x14\n\x10INVOKE_CHAINCODE\x10\x0b\x12\x0c\n\x08RESPONSE\x10\r\x12\x16\n\x12GET_STATE_BY_RANGE\x10\x0e\x12\x14\n\x10GET_QUERY_RESULT\x10\x0f\x12\x14\n\x10QUERY_STATE_NEXT\x10\x10\x12\x15\n\x11QUERY_STATE_CLOSE\x10\x11\x12\r\n\tKEEPALIVE\x10\x12\x12\x17\n\x13GET_HISTORY_FOR_KEY\x10\x13\x12\x16\n\x12GET_STATE_METADATA\x10\x14\x12\x16\n\x12PUT_STATE_METADATA\x10\x15\x12\x19\n\x15GET_PRIVATE_DATA_HASH\x10\x16\"+\n\x08GetState\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x12\n\ncollection\x18\x02 \x01(\t\"3\n\x10GetStateMetadata\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x12\n\ncollection\x18\x02 \x01(\t\":\n\x08PutState\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c\x12\x12\n\ncollection\x18\x03 \x01(\t\"\\\n\x10PutStateMetadata\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x12\n\ncollection\x18\x03 \x01(\t\x12\'\n\x08metadata\x18\x04 \x01(\x0b\x32\x15.protos.StateMetadata\"+\n\x08\x44\x65lState\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x12\n\ncollection\x18\x02 \x01(\t\"Y\n\x0fGetStateByRange\x12\x10\n\x08startKey\x18\x01 \x01(\t\x12\x0e\n\x06\x65ndKey\x18\x02 \x01(\t\x12\x12\n\ncollection\x18\x03 \x01(\t\x12\x10\n\x08metadata\x18\x04 \x01(\x0c\"E\n\x0eGetQueryResult\x12\r\n\x05query\x18\x01 \x01(\t\x12\x12\n\ncollection\x18\x02 \x01(\t\x12\x10\n\x08metadata\x18\x03 \x01(\x0c\"3\n\rQueryMetadata\x12\x10\n\x08pageSize\x18\x01 \x01(\x05\x12\x10\n\x08\x62ookmark\x18\x02 \x01(\t\"\x1f\n\x10GetHistoryForKey\x12\x0b\n\x03key\x18\x01 \x01(\t\"\x1c\n\x0eQueryStateNext\x12\n\n\x02id\x18\x01 \x01(\t\"\x1d\n\x0fQueryStateClose\x12\n\n\x02id\x18\x01 \x01(\t\"\'\n\x10QueryResultBytes\x12\x13\n\x0bresultBytes\x18\x01 \x01(\x0c\"j\n\rQueryResponse\x12)\n\x07results\x18\x01 \x03(\x0b\x32\x18.protos.QueryResultBytes\x12\x10\n\x08has_more\x18\x02 \x01(\x08\x12\n\n\x02id\x18\x03 \x01(\t\x12\x10\n\x08metadata\x18\x04 \x01(\x0c\"H\n\x15QueryResponseMetadata\x12\x1d\n\x15\x66\x65tched_records_count\x18\x01 \x01(\x05\x12\x10\n\x08\x62ookmark\x18\x02 \x01(\t\"/\n\rStateMetadata\x12\x0f\n\x07metakey\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c\"=\n\x13StateMetadataResult\x12&\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x15.protos.StateMetadata2V\n\x10\x43haincodeSupport\x12\x42\n\x08Register\x12\x18.protos.ChaincodeMessage\x1a\x18.protos.ChaincodeMessage(\x01\x30\x01\x32N\n\tChaincode\x12\x41\n\x07\x43onnect\x12\x18.protos.ChaincodeMessage\x1a\x18.protos.ChaincodeMessage(\x01\x30\x01\x42R\n\"org.hyperledger.fabric.protos.peerZ,github.com/hyperledger/fabric-protos-go/peerb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'peer.chaincode_shim_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"org.hyperledger.fabric.protos.peerZ,github.com/hyperledger/fabric-protos-go/peer'
  _CHAINCODEMESSAGE._serialized_start=120
  _CHAINCODEMESSAGE._serialized_end=777
  _CHAINCODEMESSAGE_TYPE._serialized_start=375
  _CHAINCODEMESSAGE_TYPE._serialized_end=777
  _GETSTATE._serialized_start=779
  _GETSTATE._serialized_end=822
  _GETSTATEMETADATA._serialized_start=824
  _GETSTATEMETADATA._serialized_end=875
  _PUTSTATE._serialized_start=877
  _PUTSTATE._serialized_end=935
  _PUTSTATEMETADATA._serialized_start=937
  _PUTSTATEMETADATA._serialized_end=1029
  _DELSTATE._serialized_start=1031
  _DELSTATE._serialized_end=1074
  _GETSTATEBYRANGE._serialized_start=1076
  _GETSTATEBYRANGE._serialized_end=1165
  _GETQUERYRESULT._serialized_start=1167
  _GETQUERYRESULT._serialized_end=1236
  _QUERYMETADATA._serialized_start=1238
  _QUERYMETADATA._serialized_end=1289
  _GETHISTORYFORKEY._serialized_start=1291
  _GETHISTORYFORKEY._serialized_end=1322
  _QUERYSTATENEXT._serialized_start=1324
  _QUERYSTATENEXT._serialized_end=1352
  _QUERYSTATECLOSE._serialized_start=1354
  _QUERYSTATECLOSE._serialized_end=1383
  _QUERYRESULTBYTES._serialized_start=1385
  _QUERYRESULTBYTES._serialized_end=1424
  _QUERYRESPONSE._serialized_start=1426
  _QUERYRESPONSE._serialized_end=1532
  _QUERYRESPONSEMETADATA._serialized_start=1534
  _QUERYRESPONSEMETADATA._serialized_end=1606
  _STATEMETADATA._serialized_start=1608
  _STATEMETADATA._serialized_end=1655
  _STATEMETADATARESULT._serialized_start=1657
  _STATEMETADATARESULT._serialized_end=1718
  _CHAINCODESUPPORT._serialized_start=1720
  _CHAINCODESUPPORT._serialized_end=1806
  _CHAINCODE._serialized_start=1808
  _CHAINCODE._serialized_end=1886
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: peer/query.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10peer/query.proto\x12\x06protos\"C\n\x16\x43haincodeQueryResponse\x12)\n\nchaincodes\x18\x01 \x03(\x0b\x32\x15.protos.ChaincodeInfo\"s\n\rChaincodeInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\x12\r\n\x05input\x18\x04 \x01(\t\x12\x0c\n\x04\x65scc\x18\x05 \x01(\t\x12\x0c\n\x04vscc\x18\x06 \x01(\t\x12\n\n\x02id\x18\x07 \x01(\x0c\"=\n\x14\x43hannelQueryResponse\x12%\n\x08\x63hannels\x18\x01 \x03(\x0b\x32\x13.protos.ChannelInfo\"!\n\x0b\x43hannelInfo\x12\x12\n\nchannel_id\x18\x01 \x01(\t\"O\n\x14JoinBySnapshotStatus\x12\x13\n\x0bin_progress\x18\x01 \x01(\x08\x12\"\n\x1a\x62ootstrapping_snapshot_dir\x18\x02 \x01(\tBR\n\"org.hyperledger.fabric.protos.peerZ,github.com/hyperledger/fabric-protos-go/peerb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'peer.query_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"org.hyperledger.fabric.protos.peerZ,github.com/hyperledger/fabric-protos-go/peer'
  _CHAINCODEQUERYRESPONSE._serialized_start=28
  _CHAINCODEQUERYRESPONSE._serialized_end=95
  _CHAINCODEINFO._serialized_start=97
  _CHAINCODEINFO._serialized_end=212
  _CHANNELQUERYRESPONSE._serialized_start=214
  _CHANNELQUERYRESPONSE._serialized_end=275
  _CHANNELINFO._serialized_start=277
  _CHANNELINFO._serialized_end=310
  _JOINBYSNAPSHOTSTATUS._serialized_start=312
  _JOINBYSNAPSHOTSTATUS._serialized_end=391
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gateway/gateway.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fabric_protos_python.peer import chaincode_event_pb2 as peer_dot_chaincode__event__pb2
from fabric_protos_python.peer import proposal_pb2 as peer_dot_proposal__pb2
from fabric_protos_python.peer import proposal_response_pb2 as peer_dot_proposal__response__pb2
from fabric_protos_python.peer import transaction_pb2 as peer_dot_transaction__pb2
from fabric_protos_python.common import common_pb2 as common_dot_common__pb2
from fabric_protos_python.orderer import ab_pb2 as orderer_dot_ab__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15gateway/gateway.proto\x12\x07gateway\x1a\x1apeer/chaincode_event.proto\x1a\x13peer/proposal.proto\x1a\x1cpeer/proposal_response.proto\x1a\x16peer/transaction.proto\x1a\x13\x63ommon/common.proto\x1a\x10orderer/ab.proto\"\x93\x01\n\x0e\x45ndorseRequest\x12\x16\n\x0etransaction_id\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t\x12\x34\n\x14proposed_transaction\x18\x03 \x01(\x0b\x32\x16.protos.SignedProposal\x12\x1f\n\x17\x65ndorsing_organizations\x18\x04 \x03(\t\"A\n\x0f\x45ndorseResponse\x12.\n\x14prepared_transaction\x18\x01 \x01(\x0b\x32\x10.common.Envelope\"k\n\rSubmitRequest\x12\x16\n\x0etransaction_id\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t\x12.\n\x14prepared_transaction\x18\x03 \x01(\x0b\x32\x10.common.Envelope\"\x10\n\x0eSubmitResponse\"?\n\x19SignedCommitStatusRequest\x12\x0f\n\x07request\x18\x01 \x01(\x0c\x12\x11\n\tsignature\x18\x02 \x01(\x0c\"S\n\x13\x43ommitStatusRequest\x12\x16\n\x0etransaction_id\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t\x12\x10\n\x08identity\x18\x03 \x01(\x0c\"V\n\x14\x43ommitStatusResponse\x12(\n\x06result\x18\x01 \x01(\x0e\x32\x18.protos.TxValidationCode\x12\x14\n\x0c\x62lock_number\x18\x02 \x01(\x04\"\x91\x01\n\x0f\x45valuateRequest\x12\x16\n\x0etransaction_id\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t\x12\x34\n\x14proposed_transaction\x18\x03 \x01(\x0b\x32\x16.protos.SignedProposal\x12\x1c\n\x14target_organizations\x18\x04 \x03(\t\"4\n\x10\x45valuateResponse\x12 \n\x06result\x18\x01 \x01(\x0b\x32\x10.protos.Response\"B\n\x1cSignedChaincodeEventsRequest\x12\x0f\n\x07request\x18\x01 \x01(\x0c\x12\x11\n\tsignature\x18\x02 \x01(\x0c\"\x83\x01\n\x16\x43haincodeEventsRequest\x12\x12\n\nchannel_id\x18\x01 \x01(\t\x12\x14\n\x0c\x63haincode_id\x18\x02 \x01(\t\x12\x10\n\x08identity\x18\x03 \x01(\x0c\x12-\n\x0estart_position\x18\x04 \x01(\x0b\x32\x15.orderer.SeekPosition\"W\n\x17\x43haincodeEventsResponse\x12&\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x16.protos.ChaincodeEvent\x12\x14\n\x0c\x62lock_number\x18\x02 \x01(\x04\"?\n\x0b\x45rrorDetail\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0e\n\x06msp_id\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\"x\n\x13ProposedTransaction\x12\x16\n\x0etransaction_id\x18\x01 \x01(\t\x12(\n\x08proposal\x18\x02 \x01(\x0b\x32\x16.protos.SignedProposal\x12\x1f\n\x17\x65ndorsing_organizations\x18\x03 \x03(\t\"Q\n\x13PreparedTransaction\x12\x16\n\x0etransaction_id\x18\x01 \x01(\t\x12\"\n\x08\x65nvelope\x18\x02 \x01(\x0b\x32\x10.common.Envelope2\xf4\x02\n\x07Gateway\x12<\n\x07\x45ndorse\x12\x17.gateway.EndorseRequest\x1a\x18.gateway.EndorseResponse\x12\x39\n\x06Submit\x12\x16.gateway.SubmitRequest\x1a\x17.gateway.SubmitResponse\x12Q\n\x0c\x43ommitStatus\x12\".gateway.SignedCommitStatusRequest\x1a\x1d.gateway.CommitStatusResponse\x12?\n\x08\x45valuate\x12\x18.gateway.EvaluateRequest\x1a\x19.gateway.EvaluateResponse\x12\\\n\x0f\x43haincodeEvents\x12%.gateway.SignedChaincodeEventsRequest\x1a .gateway.ChaincodeEventsResponse0\x01\x42h\n%org.hyperledger.fabric.protos.gatewayB\x0cGatewayProtoP\x01Z/github.com/hyperledger/fabric-protos-go/gatewayb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.gateway_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%org.hyperledger.fabric.protos.gatewayB\014GatewayProtoP\001Z/github.com/hyperledger/fabric-protos-go/gateway'
  _ENDORSEREQUEST._serialized_start=177
  _ENDORSEREQUEST._serialized_end=324
  _ENDORSERESPONSE._serialized_start=326
  _ENDORSERESPONSE._serialized_end=391
  _SUBMITREQUEST._serialized_start=393
  _SUBMITREQUEST._serialized_end=500
  _SUBMITRESPONSE._serialized_start=502
  _SUBMITRESPONSE._serialized_end=518
  _SIGNEDCOMMITSTATUSREQUEST._serialized_start=520
  _SIGNEDCOMMITSTATUSREQUEST._serialized_end=583
  _COMMITSTATUSREQUEST._serialized_start=585
  _COMMITSTATUSREQUEST._serialized_end=668
  _COMMITSTATUSRESPONSE._serialized_start=670
  _COMMITSTATUSRESPONSE._serialized_end=756
  _EVALUATEREQUEST._serialized_start=759
  _EVALUATEREQUEST._serialized_end=904
  _EVALUATERESPONSE._serialized_start=906
  _EVALUATERESPONSE._serialized_end=958
  _SIGNEDCHAINCODEEVENTSREQUEST._serialized_start=960
  _SIGNEDCHAINCODEEVENTSREQUEST._serialized_end=1026
  _CHAINCODEEVENTSREQUEST._serialized_start=1029
  _CHAINCODEEVENTSREQUEST._serialized_end=1160
  _CHAINCODEEVENTSRESPONSE._serialized_start=1162
  _CHAINCODEEVENTSRESPONSE._serialized_end=1249
  _ERRORDETAIL._serialized_start=1251
  _ERRORDETAIL._serialized_end=1314
  _PROPOSEDTRANSACTION._serialized_start=1316
  _PROPOSEDTRANSACTION._serialized_end=1436
  _PREPAREDTRANSACTION._serialized_start=1438
  _PREPAREDTRANSACTION._serialized_end=1519
  _GATEWAY._serialized_start=1522
  _GATEWAY._serialized_end=1894
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: peer/snapshot.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from fabric_protos_python.common import common_pb2 as common_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13peer/snapshot.proto\x12\x06protos\x1a\x1bgoogle/protobuf/empty.proto\x1a\x13\x63ommon/common.proto\"n\n\x0fSnapshotRequest\x12\x31\n\x10signature_header\x18\x01 \x01(\x0b\x32\x17.common.SignatureHeader\x12\x12\n\nchannel_id\x18\x02 \x01(\t\x12\x14\n\x0c\x62lock_number\x18\x03 \x01(\x04\"V\n\rSnapshotQuery\x12\x31\n\x10signature_header\x18\x01 \x01(\x0b\x32\x17.common.SignatureHeader\x12\x12\n\nchannel_id\x18\x02 \x01(\t\";\n\x15SignedSnapshotRequest\x12\x0f\n\x07request\x18\x01 \x01(\x0c\x12\x11\n\tsignature\x18\x02 \x01(\x0c\"6\n\x1dQueryPendingSnapshotsResponse\x12\x15\n\rblock_numbers\x18\x01 \x03(\x04\x32\xeb\x01\n\x08Snapshot\x12\x43\n\x08Generate\x12\x1d.protos.SignedSnapshotRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x41\n\x06\x43\x61ncel\x12\x1d.protos.SignedSnapshotRequest\x1a\x16.google.protobuf.Empty\"\x00\x12W\n\rQueryPendings\x12\x1d.protos.SignedSnapshotRequest\x1a%.protos.QueryPendingSnapshotsResponse\"\x00\x42R\n\"org.hyperledger.fabric.protos.peerZ,github.com/hyperledger/fabric-protos-go/peerb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'peer.snapshot_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"org.hyperledger.fabric.protos.peerZ,github.com/hyperledger/fabric-protos-go/peer'
  _SNAPSHOTREQUEST._serialized_start=81
  _SNAPSHOTREQUEST._serialized_end=191
  _SNAPSHOTQUERY._serialized_start=193
  _SNAPSHOTQUERY._serialized_end=279
  _SIGNEDSNAPSHOTREQUEST._serialized_start=281
  _SIGNEDSNAPSHOTREQUEST._serialized_end=340
  _QUERYPENDINGSNAPSHOTSRESPONSE._serialized_start=342
  _QUERYPENDINGSNAPSHOTSRESPONSE._serialized_end=396
  _SNAPSHOT._serialized_start=399
  _SNAPSHOT._serialized_end=634
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common/collection.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fabric_protos_python.common import policies_pb2 as common_dot_policies__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x63ommon/collection.proto\x12\x06\x63ommon\x1a\x15\x63ommon/policies.proto\"G\n\x17\x43ollectionConfigPackage\x12(\n\x06\x63onfig\x18\x01 \x03(\x0b\x32\x18.common.CollectionConfig:\x02\x18\x01\"e\n\x10\x43ollectionConfig\x12\x42\n\x18static_collection_config\x18\x01 \x01(\x0b\x32\x1e.common.StaticCollectionConfigH\x00:\x02\x18\x01\x42\t\n\x07payload\"\xa2\x02\n\x16StaticCollectionConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12:\n\x12member_orgs_policy\x18\x02 \x01(\x0b\x32\x1e.common.CollectionPolicyConfig\x12\x1b\n\x13required_peer_count\x18\x03 \x01(\x05\x12\x1a\n\x12maximum_peer_count\x18\x04 \x01(\x05\x12\x15\n\rblock_to_live\x18\x05 \x01(\x04\x12\x18\n\x10member_only_read\x18\x06 \x01(\x08\x12\x19\n\x11member_only_write\x18\x07 \x01(\x08\x12\x35\n\x12\x65ndorsement_policy\x18\x08 \x01(\x0b\x32\x19.common.ApplicationPolicy:\x02\x18\x01\"d\n\x16\x43ollectionPolicyConfig\x12;\n\x10signature_policy\x18\x01 \x01(\x0b\x32\x1f.common.SignaturePolicyEnvelopeH\x00:\x02\x18\x01\x42\t\n\x07payloadBV\n$org.hyperledger.fabric.protos.commonZ.github.com/hyperledger/fabric-protos-go/commonb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'common.collection_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$org.hyperledger.fabric.protos.commonZ.github.com/hyperledger/fabric-protos-go/common'
  _COLLECTIONCONFIGPACKAGE._options = None
  _COLLECTIONCONFIGPACKAGE._serialized_options = b'\030\001'
  _COLLECTIONCONFIG._options = None
  _COLLECTIONCONFIG._serialized_options = b'\030\001'
  _STATICCOLLECTIONCONFIG._options = None
  _STATICCOLLECTIONCONFIG._serialized_options = b'\030\001'
  _COLLECTIONPOLICYCONFIG._options = None
  _COLLECTIONPOLICYCONFIG._serialized_options = b'\030\001'
  _COLLECTIONCONFIGPACKAGE._serialized_start=58
  _COLLECTIONCONFIGPACKAGE._serialized_end=129
  _COLLECTIONCONFIG._serialized_start=131
  _COLLECTIONCONFIG._serialized_end=232
  _STATICCOLLECTIONCONFIG._serialized_start=235
  _STATICCOLLECTIONCONFIG._serialized_end=525
  _COLLECTIONPOLICYCONFIG._serialized_start=527
  _COLLECTIONPOLICYCONFIG._serialized_end=627
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: orderer/etcdraft/configuration.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$orderer/etcdraft/configuration.proto\x12\x08\x65tcdraft\"]\n\x0e\x43onfigMetadata\x12\'\n\nconsenters\x18\x01 \x03(\x0b\x32\x13.etcdraft.Consenter\x12\"\n\x07options\x18\x02 \x01(\x0b\x32\x11.etcdraft.Options\"Y\n\tConsenter\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\r\x12\x17\n\x0f\x63lient_tls_cert\x18\x03 \x01(\x0c\x12\x17\n\x0fserver_tls_cert\x18\x04 \x01(\x0c\"\x8c\x01\n\x07Options\x12\x15\n\rtick_interval\x18\x01 \x01(\t\x12\x15\n\relection_tick\x18\x02 \x01(\r\x12\x16\n\x0eheartbeat_tick\x18\x03 \x01(\r\x12\x1b\n\x13max_inflight_blocks\x18\x04 \x01(\r\x12\x1e\n\x16snapshot_interval_size\x18\x05 \x01(\rBj\n.org.hyperledger.fabric.protos.orderer.etcdraftZ8github.com/hyperledger/fabric-protos-go/orderer/etcdraftb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'orderer.etcdraft.configuration_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n.org.hyperledger.fabric.protos.orderer.etcdraftZ8github.com/hyperledger/fabric-protos-go/orderer/etcdraft'
  _CONFIGMETADATA._serialized_start=50
  _CONFIGMETADATA._serialized_end=143
  _CONSENTER._serialized_start=145
  _CONSENTER._serialized_end=234
  _OPTIONS._serialized_start=237
  _OPTIONS._serialized_end=377
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: peer/peer.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fabric_protos_python.peer import proposal_pb2 as peer_dot_proposal__pb2
from fabric_protos_python.peer import proposal_response_pb2 as peer_dot_proposal__response__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fpeer/peer.proto\x12\x06protos\x1a\x13peer/proposal.proto\x1a\x1cpeer/proposal_response.proto2O\n\x08\x45ndorser\x12\x43\n\x0fProcessProposal\x12\x16.protos.SignedProposal\x1a\x18.protos.ProposalResponseBR\n\"org.hyperledger.fabric.protos.peerZ,github.com/hyperledger/fabric-protos-go/peerb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'peer.peer_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"org.hyperledger.fabric.protos.peerZ,github.com/hyperledger/fabric-protos-go/peer'
  _ENDORSER._serialized_start=78
  _ENDORSER._serialized_end=157
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: discovery/protocol.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fabric_protos_python.gossip import message_pb2 as gossip_dot_message__pb2
from fabric_protos_python.msp import msp_config_pb2 as msp_dot_msp__config__pb2
from fabric_protos_python.peer import proposal_response_pb2 as peer_dot_proposal__response__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x64iscovery/protocol.proto\x12\tdiscovery\x1a\x14gossip/message.proto\x1a\x14msp/msp_config.proto\x1a\x1cpeer/proposal_response.proto\"3\n\rSignedRequest\x12\x0f\n\x07payload\x18\x01 \x01(\x0c\x12\x11\n\tsignature\x18\x02 \x01(\x0c\"Y\n\x07Request\x12+\n\x0e\x61uthentication\x18\x01 \x01(\x0b\x32\x13.discovery.AuthInfo\x12!\n\x07queries\x18\x02 \x03(\x0b\x32\x10.discovery.Query\"3\n\x08Response\x12\'\n\x07results\x18\x01 \x03(\x0b\x32\x16.discovery.QueryResult\"A\n\x08\x41uthInfo\x12\x17\n\x0f\x63lient_identity\x18\x01 \x01(\x0c\x12\x1c\n\x14\x63lient_tls_cert_hash\x18\x02 \x01(\x0c\"\xe8\x01\n\x05Query\x12\x0f\n\x07\x63hannel\x18\x01 \x01(\t\x12.\n\x0c\x63onfig_query\x18\x02 \x01(\x0b\x32\x16.discovery.ConfigQueryH\x00\x12\x34\n\npeer_query\x18\x03 \x01(\x0b\x32\x1e.discovery.PeerMembershipQueryH\x00\x12-\n\x08\x63\x63_query\x18\x04 \x01(\x0b\x32\x19.discovery.ChaincodeQueryH\x00\x12\x30\n\x0blocal_peers\x18\x05 \x01(\x0b\x32\x19.discovery.LocalPeerQueryH\x00\x42\x07\n\x05query\"\xd9\x01\n\x0bQueryResult\x12!\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x10.discovery.ErrorH\x00\x12\x30\n\rconfig_result\x18\x02 \x01(\x0b\x32\x17.discovery.ConfigResultH\x00\x12\x37\n\x0c\x63\x63_query_res\x18\x03 \x01(\x0b\x32\x1f.discovery.ChaincodeQueryResultH\x00\x12\x32\n\x07members\x18\x04 \x01(\x0b\x32\x1f.discovery.PeerMembershipResultH\x00\x42\x08\n\x06result\"\r\n\x0b\x43onfigQuery\"\x82\x02\n\x0c\x43onfigResult\x12/\n\x04msps\x18\x01 \x03(\x0b\x32!.discovery.ConfigResult.MspsEntry\x12\x37\n\x08orderers\x18\x02 \x03(\x0b\x32%.discovery.ConfigResult.OrderersEntry\x1a\x41\n\tMspsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.msp.FabricMSPConfig:\x02\x38\x01\x1a\x45\n\rOrderersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.discovery.Endpoints:\x02\x38\x01\"@\n\x13PeerMembershipQuery\x12)\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x19.protos.ChaincodeInterest\"\xa2\x01\n\x14PeerMembershipResult\x12\x45\n\x0cpeers_by_org\x18\x01 \x03(\x0b\x32/.discovery.PeerMembershipResult.PeersByOrgEntry\x1a\x43\n\x0fPeersByOrgEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1f\n\x05value\x18\x02 \x01(\x0b\x32\x10.discovery.Peers:\x02\x38\x01\">\n\x0e\x43haincodeQuery\x12,\n\tinterests\x18\x01 \x03(\x0b\x32\x19.protos.ChaincodeInterest\"I\n\x14\x43haincodeQueryResult\x12\x31\n\x07\x63ontent\x18\x01 \x03(\x0b\x32 .discovery.EndorsementDescriptor\"\x10\n\x0eLocalPeerQuery\"\xf0\x01\n\x15\x45ndorsementDescriptor\x12\x11\n\tchaincode\x18\x01 \x01(\t\x12T\n\x13\x65ndorsers_by_groups\x18\x02 \x03(\x0b\x32\x37.discovery.EndorsementDescriptor.EndorsersByGroupsEntry\x12\"\n\x07layouts\x18\x03 \x03(\x0b\x32\x11.discovery.Layout\x1aJ\n\x16\x45ndorsersByGroupsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1f\n\x05value\x18\x02 \x01(\x0b\x32\x10.discovery.Peers:\x02\x38\x01\"\x89\x01\n\x06Layout\x12\x45\n\x13quantities_by_group\x18\x01 \x03(\x0b\x32(.discovery.Layout.QuantitiesByGroupEntry\x1a\x38\n\x16QuantitiesByGroupEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\r:\x02\x38\x01\"\'\n\x05Peers\x12\x1e\n\x05peers\x18\x01 \x03(\x0b\x32\x0f.discovery.Peer\"i\n\x04Peer\x12$\n\nstate_info\x18\x01 \x01(\x0b\x32\x10.gossip.Envelope\x12)\n\x0fmembership_info\x18\x02 \x01(\x0b\x32\x10.gossip.Envelope\x12\x10\n\x08identity\x18\x03 \x01(\x0c\"\x18\n\x05\x45rror\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\"2\n\tEndpoints\x12%\n\x08\x65ndpoint\x18\x01 \x03(\x0b\x32\x13.discovery.Endpoint\"&\n\x08\x45ndpoint\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\r2F\n\tDiscovery\x12\x39\n\x08\x44iscover\x12\x18.discovery.SignedRequest\x1a\x13.discovery.ResponseB\\\n\'org.hyperledger.fabric.protos.discoveryZ1github.com/hyperledger/fabric-protos-go/discoveryb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'discovery.protocol_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\'org.hyperledger.fabric.protos.discoveryZ1github.com/hyperledger/fabric-protos-go/discovery'
  _CONFIGRESULT_MSPSENTRY._options = None
  _CONFIGRESULT_MSPSENTRY._serialized_options = b'8\001'
  _CONFIGRESULT_ORDERERSENTRY._options = None
  _CONFIGRESULT_ORDERERSENTRY._serialized_options = b'8\001'
  _PEERMEMBERSHIPRESULT_PEERSBYORGENTRY._options = None
  _PEERMEMBERSHIPRESULT_PEERSBYORGENTRY._serialized_options = b'8\001'
  _ENDORSEMENTDESCRIPTOR_ENDORSERSBYGROUPSENTRY._options = None
  _ENDORSEMENTDESCRIPTOR_ENDORSERSBYGROUPSENTRY._serialized_options = b'8\001'
  _LAYOUT_QUANTITIESBYGROUPENTRY._options = None
  _LAYOUT_QUANTITIESBYGROUPENTRY._serialized_options = b'8\001'
  _SIGNEDREQUEST._serialized_start=113
  _SIGNEDREQUEST._serialized_end=164
  _REQUEST._serialized_start=166
  _REQUEST._serialized_end=255
  _RESPONSE._serialized_start=257
  _RESPONSE._serialized_end=308
  _AUTHINFO._serialized_start=310
  _AUTHINFO._serialized_end=375
  _QUERY._serialized_start=378
  _QUERY._serialized_end=610
  _QUERYRESULT._serialized_start=613
  _QUERYRESULT._serialized_end=830
  _CONFIGQUERY._serialized_start=832
  _CONFIGQUERY._serialized_end=845
  _CONFIGRESULT._serialized_start=848
  _CONFIGRESULT._serialized_end=1106
  _CONFIGRESULT_MSPSENTRY._serialized_start=970
  _CONFIGRESULT_MSPSENTRY._serialized_end=1035
  _CONFIGRESULT_ORDERERSENTRY._serialized_start=1037
  _CONFIGRESULT_ORDERERSENTRY._serialized_end=1106
  _PEERMEMBERSHIPQUERY._serialized_start=1108
  _PEERMEMBERSHIPQUERY._serialized_end=1172
  _PEERMEMBERSHIPRESULT._serialized_start=1175
  _PEERMEMBERSHIPRESULT._serialized_end=1337
  _PEERMEMBERSHIPRESULT_PEERSBYORGENTRY._serialized_start=1270
  _PEERMEMBERSHIPRESULT_PEERSBYORGENTRY._serialized_end=1337
  _CHAINCODEQUERY._serialized_start=1339
  _CHAINCODEQUERY._serialized_end=1401
  _CHAINCODEQUERYRESULT._serialized_start=1403
  _CHAINCODEQUERYRESULT._serialized_end=1476
  _LOCALPEERQUERY._serialized_start=1478
  _LOCALPEERQUERY._serialized_end=1494
  _ENDORSEMENTDESCRIPTOR._serialized_start=1497
  _ENDORSEMENTDESCRIPTOR._serialized_end=1737
  _ENDORSEMENTDESCRIPTOR_ENDORSERSBYGROUPSENTRY._serialized_start=1663
  _ENDORSEMENTDESCRIPTOR_ENDORSERSBYGROUPSENTRY._serialized_end=1737
  _LAYOUT._serialized_start=1740
  _LAYOUT._serialized_end=1877
  _LAYOUT_QUANTITIESBYGROUPENTRY._serialized_start=1821
  _LAYOUT_QUANTITIESBYGROUPENTRY._serialized_end=1877
  _PEERS._serialized_start=1879
  _PEERS._serialized_end=1918
  _PEER._serialized_start=1920
  _PEER._serialized_end=2025
  _ERROR._serialized_start=2027
  _ERROR._serialized_end=2051
  _ENDPOINTS._serialized_start=2053
  _ENDPOINTS._serialized_end=2103
  _ENDPOINT._serialized_start=2105
  _ENDPOINT._serialized_end=2143
  _DISCOVERY._serialized_start=2145
  _DISCOVERY._serialized_end=2215
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: peer/lifecycle/chaincode_definition.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)peer/lifecycle/chaincode_definition.proto\x12\tlifecycle\"^\n\x18\x43haincodeEndorsementInfo\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x15\n\rinit_required\x18\x02 \x01(\x08\x12\x1a\n\x12\x65ndorsement_plugin\x18\x03 \x01(\t\"R\n\x17\x43haincodeValidationInfo\x12\x19\n\x11validation_plugin\x18\x01 \x01(\t\x12\x1c\n\x14validation_parameter\x18\x02 \x01(\x0c\x42\x66\n,org.hyperledger.fabric.protos.peer.lifecycleZ6github.com/hyperledger/fabric-protos-go/peer/lifecycleb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'peer.lifecycle.chaincode_definition_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n,org.hyperledger.fabric.protos.peer.lifecycleZ6github.com/hyperledger/fabric-protos-go/peer/lifecycle'
  _CHAINCODEENDORSEMENTINFO._serialized_start=56
  _CHAINCODEENDORSEMENTINFO._serialized_end=150
  _CHAINCODEVALIDATIONINFO._serialized_start=152
  _CHAINCODEVALIDATIONINFO._serialized_end=234
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: orderer/ab.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fabric_protos_python.common import common_pb2 as common_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10orderer/ab.proto\x12\x07orderer\x1a\x13\x63ommon/common.proto\"A\n\x11\x42roadcastResponse\x12\x1e\n\x06status\x18\x01 \x01(\x0e\x32\x0e.common.Status\x12\x0c\n\x04info\x18\x02 \x01(\t\"\x0c\n\nSeekNewest\"\x0c\n\nSeekOldest\"\x1f\n\rSeekSpecified\x12\x0e\n\x06number\x18\x01 \x01(\x04\"\x10\n\x0eSeekNextCommit\"\xc1\x01\n\x0cSeekPosition\x12%\n\x06newest\x18\x01 \x01(\x0b\x32\x13.orderer.SeekNewestH\x00\x12%\n\x06oldest\x18\x02 \x01(\x0b\x32\x13.orderer.SeekOldestH\x00\x12+\n\tspecified\x18\x03 \x01(\x0b\x32\x16.orderer.SeekSpecifiedH\x00\x12.\n\x0bnext_commit\x18\x04 \x01(\x0b\x32\x17.orderer.SeekNextCommitH\x00\x42\x06\n\x04Type\"\xb4\x02\n\x08SeekInfo\x12$\n\x05start\x18\x01 \x01(\x0b\x32\x15.orderer.SeekPosition\x12#\n\x04stop\x18\x02 \x01(\x0b\x32\x15.orderer.SeekPosition\x12\x30\n\x08\x62\x65havior\x18\x03 \x01(\x0e\x32\x1e.orderer.SeekInfo.SeekBehavior\x12;\n\x0e\x65rror_response\x18\x04 \x01(\x0e\x32#.orderer.SeekInfo.SeekErrorResponse\"<\n\x0cSeekBehavior\x12\x15\n\x11\x42LOCK_UNTIL_READY\x10\x00\x12\x15\n\x11\x46\x41IL_IF_NOT_READY\x10\x01\"0\n\x11SeekErrorResponse\x12\n\n\x06STRICT\x10\x00\x12\x0f\n\x0b\x42\x45ST_EFFORT\x10\x01\"[\n\x0f\x44\x65liverResponse\x12 \n\x06status\x18\x01 \x01(\x0e\x32\x0e.common.StatusH\x00\x12\x1e\n\x05\x62lock\x18\x02 \x01(\x0b\x32\r.common.BlockH\x00\x42\x06\n\x04Type2\x8b\x01\n\x0f\x41tomicBroadcast\x12=\n\tBroadcast\x12\x10.common.Envelope\x1a\x1a.orderer.BroadcastResponse(\x01\x30\x01\x12\x39\n\x07\x44\x65liver\x12\x10.common.Envelope\x1a\x18.orderer.DeliverResponse(\x01\x30\x01\x42X\n%org.hyperledger.fabric.protos.ordererZ/github.com/hyperledger/fabric-protos-go/ordererb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'orderer.ab_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%org.hyperledger.fabric.protos.ordererZ/github.com/hyperledger/fabric-protos-go/orderer'
  _BROADCASTRESPONSE._serialized_start=50
  _BROADCASTRESPONSE._serialized_end=115
  _SEEKNEWEST._serialized_start=117
  _SEEKNEWEST._serialized_end=129
  _SEEKOLDEST._serialized_start=131
  _SEEKOLDEST._serialized_end=143
  _SEEKSPECIFIED._serialized_start=145
  _SEEKSPECIFIED._serialized_end=176
  _SEEKNEXTCOMMIT._serialized_start=178
  _SEEKNEXTCOMMIT._serialized_end=194
  _SEEKPOSITION._serialized_start=197
  _SEEKPOSITION._serialized_end=390
  _SEEKINFO._serialized_start=393
  _SEEKINFO._serialized_end=701
  _SEEKINFO_SEEKBEHAVIOR._serialized_start=591
  _SEEKINFO_SEEKBEHAVIOR._serialized_end=651
  _SEEKINFO_SEEKERRORRESPONSE._serialized_start=653
  _SEEKINFO_SEEKERRORRESPONSE._serialized_end=701
  _DELIVERRESPONSE._serialized_start=703
  _DELIVERRESPONSE._serialized_end=794
  _ATOMICBROADCAST._serialized_start=797
  _ATOMICBROADCAST._serialized_end=936
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: peer/transaction.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fabric_protos_python.peer import proposal_response_pb2 as peer_dot_proposal__response__pb2
from fabric_protos_python.common import common_pb2 as common_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16peer/transaction.proto\x12\x06protos\x1a\x1cpeer/proposal_response.proto\x1a\x13\x63ommon/common.proto\"]\n\x14ProcessedTransaction\x12-\n\x13transactionEnvelope\x18\x01 \x01(\x0b\x32\x10.common.Envelope\x12\x16\n\x0evalidationCode\x18\x02 \x01(\x05\"9\n\x0bTransaction\x12*\n\x07\x61\x63tions\x18\x01 \x03(\x0b\x32\x19.protos.TransactionAction\"4\n\x11TransactionAction\x12\x0e\n\x06header\x18\x01 \x01(\x0c\x12\x0f\n\x07payload\x18\x02 \x01(\x0c\"m\n\x16\x43haincodeActionPayload\x12\"\n\x1a\x63haincode_proposal_payload\x18\x01 \x01(\x0c\x12/\n\x06\x61\x63tion\x18\x02 \x01(\x0b\x32\x1f.protos.ChaincodeEndorsedAction\"g\n\x17\x43haincodeEndorsedAction\x12!\n\x19proposal_response_payload\x18\x01 \x01(\x0c\x12)\n\x0c\x65ndorsements\x18\x02 \x03(\x0b\x32\x13.protos.Endorsement*\xab\x05\n\x10TxValidationCode\x12\t\n\x05VALID\x10\x00\x12\x10\n\x0cNIL_ENVELOPE\x10\x01\x12\x0f\n\x0b\x42\x41\x44_PAYLOAD\x10\x02\x12\x15\n\x11\x42\x41\x44_COMMON_HEADER\x10\x03\x12\x19\n\x15\x42\x41\x44_CREATOR_SIGNATURE\x10\x04\x12 \n\x1cINVALID_ENDORSER_TRANSACTION\x10\x05\x12\x1e\n\x1aINVALID_CONFIG_TRANSACTION\x10\x06\x12\x1a\n\x16UNSUPPORTED_TX_PAYLOAD\x10\x07\x12\x15\n\x11\x42\x41\x44_PROPOSAL_TXID\x10\x08\x12\x12\n\x0e\x44UPLICATE_TXID\x10\t\x12\x1e\n\x1a\x45NDORSEMENT_POLICY_FAILURE\x10\n\x12\x16\n\x12MVCC_READ_CONFLICT\x10\x0b\x12\x19\n\x15PHANTOM_READ_CONFLICT\x10\x0c\x12\x13\n\x0fUNKNOWN_TX_TYPE\x10\r\x12\x1a\n\x16TARGET_CHAIN_NOT_FOUND\x10\x0e\x12\x14\n\x10MARSHAL_TX_ERROR\x10\x0f\x12\x10\n\x0cNIL_TXACTION\x10\x10\x12\x15\n\x11\x45XPIRED_CHAINCODE\x10\x11\x12\x1e\n\x1a\x43HAINCODE_VERSION_CONFLICT\x10\x12\x12\x18\n\x14\x42\x41\x44_HEADER_EXTENSION\x10\x13\x12\x16\n\x12\x42\x41\x44_CHANNEL_HEADER\x10\x14\x12\x18\n\x14\x42\x41\x44_RESPONSE_PAYLOAD\x10\x15\x12\r\n\tBAD_RWSET\x10\x16\x12\x14\n\x10ILLEGAL_WRITESET\x10\x17\x12\x14\n\x10INVALID_WRITESET\x10\x18\x12\x15\n\x11INVALID_CHAINCODE\x10\x19\x12\x12\n\rNOT_VALIDATED\x10\xfe\x01\x12\x19\n\x14INVALID_OTHER_REASON\x10\xff\x01*E\n\x0cMetaDataKeys\x12\x18\n\x14VALIDATION_PARAMETER\x10\x00\x12\x1b\n\x17VALIDATION_PARAMETER_V2\x10\x01\x42\x66\n\"org.hyperledger.fabric.protos.peerB\x12TransactionPackageZ,github.com/hyperledger/fabric-protos-go/peerb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'peer.transaction_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"org.hyperledger.fabric.protos.peerB\022TransactionPackageZ,github.com/hyperledger/fabric-protos-go/peer'
  _TXVALIDATIONCODE._serialized_start=510
  _TXVALIDATIONCODE._serialized_end=1193
  _METADATAKEYS._serialized_start=1195
  _METADATAKEYS._serialized_end=1264
  _PROCESSEDTRANSACTION._serialized_start=85
  _PROCESSEDTRANSACTION._serialized_end=178
  _TRANSACTION._serialized_start=180
  _TRANSACTION._serialized_end=237
  _TRANSACTIONACTION._serialized_start=239
  _TRANSACTIONACTION._serialized_end=291
  _CHAINCODEACTIONPAYLOAD._serialized_start=293
  _CHAINCODEACTIONPAYLOAD._serialized_end=402
  _CHAINCODEENDORSEDACTION._serialized_start=404
  _CHAINCODEENDORSEDACTION._serialized_end=507
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ledger/queryresult/kv_query_result.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(ledger/queryresult/kv_query_result.proto\x12\x0bqueryresult\x1a\x1fgoogle/protobuf/timestamp.proto\"3\n\x02KV\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\x0c\"q\n\x0fKeyModification\x12\r\n\x05tx_id\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c\x12-\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\tis_delete\x18\x04 \x01(\x08\x42n\n0org.hyperledger.fabric.protos.ledger.queryresultZ:github.com/hyperledger/fabric-protos-go/ledger/queryresultb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ledger.queryresult.kv_query_result_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n0org.hyperledger.fabric.protos.ledger.queryresultZ:github.com/hyperledger/fabric-protos-go/ledger/queryresult'
  _KV._serialized_start=90
  _KV._serialized_end=141
  _KEYMODIFICATION._serialized_start=143
  _KEYMODIFICATION._serialized_end=256
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: peer/chaincode.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fabric_protos_python.common import policies_pb2 as common_dot_policies__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14peer/chaincode.proto\x12\x06protos\x1a\x15\x63ommon/policies.proto\":\n\x0b\x43haincodeID\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\"\xa1\x01\n\x0e\x43haincodeInput\x12\x0c\n\x04\x61rgs\x18\x01 \x03(\x0c\x12<\n\x0b\x64\x65\x63orations\x18\x02 \x03(\x0b\x32\'.protos.ChaincodeInput.DecorationsEntry\x12\x0f\n\x07is_init\x18\x03 \x01(\x08\x1a\x32\n\x10\x44\x65\x63orationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\xdc\x01\n\rChaincodeSpec\x12(\n\x04type\x18\x01 \x01(\x0e\x32\x1a.protos.ChaincodeSpec.Type\x12)\n\x0c\x63haincode_id\x18\x02 \x01(\x0b\x32\x13.protos.ChaincodeID\x12%\n\x05input\x18\x03 \x01(\x0b\x32\x16.protos.ChaincodeInput\x12\x0f\n\x07timeout\x18\x04 \x01(\x05\">\n\x04Type\x12\r\n\tUNDEFINED\x10\x00\x12\n\n\x06GOLANG\x10\x01\x12\x08\n\x04NODE\x10\x02\x12\x07\n\x03\x43\x41R\x10\x03\x12\x08\n\x04JAVA\x10\x04\"\x84\x01\n\x17\x43haincodeDeploymentSpec\x12-\n\x0e\x63haincode_spec\x18\x01 \x01(\x0b\x32\x15.protos.ChaincodeSpec\x12\x14\n\x0c\x63ode_package\x18\x03 \x01(\x0cJ\x04\x08\x02\x10\x03J\x04\x08\x04\x10\x05R\x0e\x65\x66\x66\x65\x63tive_dateR\x08\x65xec_env\"a\n\x17\x43haincodeInvocationSpec\x12-\n\x0e\x63haincode_spec\x18\x01 \x01(\x0b\x32\x15.protos.ChaincodeSpecJ\x04\x08\x02\x10\x03R\x11id_generation_alg\"(\n\x0eLifecycleEvent\x12\x16\n\x0e\x63haincode_name\x18\x01 \x01(\t\"-\n\x07\x43\x44SData\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\x12\x14\n\x0cmetadatahash\x18\x02 \x01(\x0c\"\xd4\x01\n\rChaincodeData\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x0c\n\x04\x65scc\x18\x03 \x01(\t\x12\x0c\n\x04vscc\x18\x04 \x01(\t\x12/\n\x06policy\x18\x05 \x01(\x0b\x32\x1f.common.SignaturePolicyEnvelope\x12\x0c\n\x04\x64\x61ta\x18\x06 \x01(\x0c\x12\n\n\x02id\x18\x07 \x01(\x0c\x12=\n\x14instantiation_policy\x18\x08 \x01(\x0b\x32\x1f.common.SignaturePolicyEnvelopeBR\n\"org.hyperledger.fabric.protos.peerZ,github.com/hyperledger/fabric-protos-go/peerb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'peer.chaincode_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"org.hyperledger.fabric.protos.peerZ,github.com/hyperledger/fabric-protos-go/peer'
  _CHAINCODEINPUT_DECORATIONSENTRY._options = None
  _CHAINCODEINPUT_DECORATIONSENTRY._serialized_options = b'8\001'
  _CHAINCODEID._serialized_start=55
  _CHAINCODEID._serialized_end=113
  _CHAINCODEINPUT._serialized_start=116
  _CHAINCODEINPUT._serialized_end=277
  _CHAINCODEINPUT_DECORATIONSENTRY._serialized_start=227
  _CHAINCODEINPUT_DECORATIONSENTRY._serialized_end=277
  _CHAINCODESPEC._serialized_start=280
  _CHAINCODESPEC._serialized_end=500
  _CHAINCODESPEC_TYPE._serialized_start=438
  _CHAINCODESPEC_TYPE._serialized_end=500
  _CHAINCODEDEPLOYMENTSPEC._serialized_start=503
  _CHAINCODEDEPLOYMENTSPEC._serialized_end=635
  _CHAINCODEINVOCATIONSPEC._serialized_start=637
  _CHAINCODEINVOCATIONSPEC._serialized_end=734
  _LIFECYCLEEVENT._serialized_start=736
  _LIFECYCLEEVENT._serialized_end=776
  _CDSDATA._serialized_start=778
  _CDSDATA._serialized_end=823
  _CHAINCODEDATA._serialized_start=826
  _CHAINCODEDATA._serialized_end=1038
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: peer/proposal.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fabric_protos_python.peer import chaincode_pb2 as peer_dot_chaincode__pb2
from fabric_protos_python.peer import proposal_response_pb2 as peer_dot_proposal__response__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13peer/proposal.proto\x12\x06protos\x1a\x14peer/chaincode.proto\x1a\x1cpeer/proposal_response.proto\";\n\x0eSignedProposal\x12\x16\n\x0eproposal_bytes\x18\x01 \x01(\x0c\x12\x11\n\tsignature\x18\x02 \x01(\x0c\">\n\x08Proposal\x12\x0e\n\x06header\x18\x01 \x01(\x0c\x12\x0f\n\x07payload\x18\x02 \x01(\x0c\x12\x11\n\textension\x18\x03 \x01(\x0c\"^\n\x18\x43haincodeHeaderExtension\x12)\n\x0c\x63haincode_id\x18\x02 \x01(\x0b\x32\x13.protos.ChaincodeIDJ\x04\x08\x01\x10\x02R\x11payload_visbility\"\xa8\x01\n\x18\x43haincodeProposalPayload\x12\r\n\x05input\x18\x01 \x01(\x0c\x12H\n\x0cTransientMap\x18\x02 \x03(\x0b\x32\x32.protos.ChaincodeProposalPayload.TransientMapEntry\x1a\x33\n\x11TransientMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\x99\x01\n\x0f\x43haincodeAction\x12\x0f\n\x07results\x18\x01 \x01(\x0c\x12\x0e\n\x06\x65vents\x18\x02 \x01(\x0c\x12\"\n\x08response\x18\x03 \x01(\x0b\x32\x10.protos.Response\x12)\n\x0c\x63haincode_id\x18\x04 \x01(\x0b\x32\x13.protos.ChaincodeIDJ\x04\x08\x05\x10\x06R\x10token_operationsBc\n\"org.hyperledger.fabric.protos.peerB\x0fProposalPackageZ,github.com/hyperledger/fabric-protos-go/peerb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'peer.proposal_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"org.hyperledger.fabric.protos.peerB\017ProposalPackageZ,github.com/hyperledger/fabric-protos-go/peer'
  _CHAINCODEPROPOSALPAYLOAD_TRANSIENTMAPENTRY._options = None
  _CHAINCODEPROPOSALPAYLOAD_TRANSIENTMAPENTRY._serialized_options = b'8\001'
  _SIGNEDPROPOSAL._serialized_start=83
  _SIGNEDPROPOSAL._serialized_end=142
  _PROPOSAL._serialized_start=144
  _PROPOSAL._serialized_end=206
  _CHAINCODEHEADEREXTENSION._serialized_start=208
  _CHAINCODEHEADEREXTENSION._serialized_end=302
  _CHAINCODEPROPOSALPAYLOAD._serialized_start=305
  _CHAINCODEPROPOSALPAYLOAD._serialized_end=473
  _CHAINCODEPROPOSALPAYLOAD_TRANSIENTMAPENTRY._serialized_start=422
  _CHAINCODEPROPOSALPAYLOAD_TRANSIENTMAPENTRY._serialized_end=473
  _CHAINCODEACTION._serialized_start=476
  _CHAINCODEACTION._serialized_end=629
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: peer/proposal_response.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from fabric_protos_python.common import policies_pb2 as common_dot_policies__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cpeer/proposal_response.proto\x12\x06protos\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x15\x63ommon/policies.proto\"\xde\x01\n\x10ProposalResponse\x12\x0f\n\x07version\x18\x01 \x01(\x05\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\"\n\x08response\x18\x04 \x01(\x0b\x32\x10.protos.Response\x12\x0f\n\x07payload\x18\x05 \x01(\x0c\x12(\n\x0b\x65ndorsement\x18\x06 \x01(\x0b\x32\x13.protos.Endorsement\x12+\n\x08interest\x18\x07 \x01(\x0b\x32\x19.protos.ChaincodeInterest\"<\n\x08Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x0f\n\x07payload\x18\x03 \x01(\x0c\"C\n\x17ProposalResponsePayload\x12\x15\n\rproposal_hash\x18\x01 \x01(\x0c\x12\x11\n\textension\x18\x02 \x01(\x0c\"2\n\x0b\x45ndorsement\x12\x10\n\x08\x65ndorser\x18\x01 \x01(\x0c\x12\x11\n\tsignature\x18\x02 \x01(\x0c\">\n\x11\x43haincodeInterest\x12)\n\nchaincodes\x18\x01 \x03(\x0b\x32\x15.protos.ChaincodeCall\"\xc6\x01\n\rChaincodeCall\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x18\n\x10\x63ollection_names\x18\x02 \x03(\t\x12\x18\n\x10no_private_reads\x18\x03 \x01(\x08\x12\x18\n\x10no_public_writes\x18\x04 \x01(\x08\x12\x35\n\x0ckey_policies\x18\x05 \x03(\x0b\x32\x1f.common.SignaturePolicyEnvelope\x12\"\n\x1a\x64isregard_namespace_policy\x18\x06 \x01(\x08\x42k\n\"org.hyperledger.fabric.protos.peerB\x17ProposalResponsePackageZ,github.com/hyperledger/fabric-protos-go/peerb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'peer.proposal_response_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"org.hyperledger.fabric.protos.peerB\027ProposalResponsePackageZ,github.com/hyperledger/fabric-protos-go/peer'
  _PROPOSALRESPONSE._serialized_start=97
  _PROPOSALRESPONSE._serialized_end=319
  _RESPONSE._serialized_start=321
  _RESPONSE._serialized_end=381
  _PROPOSALRESPONSEPAYLOAD._serialized_start=383
  _PROPOSALRESPONSEPAYLOAD._serialized_end=450
  _ENDORSEMENT._serialized_start=452
  _ENDORSEMENT._serialized_end=502
  _CHAINCODEINTEREST._serialized_start=504
  _CHAINCODEINTEREST._serialized_end=566
  _CHAINCODECALL._serialized_start=569
  _CHAINCODECALL._serialized_end=767
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: peer/lifecycle/db.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17peer/lifecycle/db.proto\x12\tlifecycle\"1\n\rStateMetadata\x12\x10\n\x08\x64\x61tatype\x18\x01 \x01(\t\x12\x0e\n\x06\x66ields\x18\x02 \x03(\t\"G\n\tStateData\x12\x0f\n\x05Int64\x18\x01 \x01(\x03H\x00\x12\x0f\n\x05\x42ytes\x18\x02 \x01(\x0cH\x00\x12\x10\n\x06String\x18\x03 \x01(\tH\x00\x42\x06\n\x04TypeBf\n,org.hyperledger.fabric.protos.peer.lifecycleZ6github.com/hyperledger/fabric-protos-go/peer/lifecycleb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'peer.lifecycle.db_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n,org.hyperledger.fabric.protos.peer.lifecycleZ6github.com/hyperledger/fabric-protos-go/peer/lifecycle'
  _STATEMETADATA._serialized_start=38
  _STATEMETADATA._serialized_end=87
  _STATEDATA._serialized_start=89
  _STATEDATA._serialized_end=160
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: msp/msp_config.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14msp/msp_config.proto\x12\x03msp\")\n\tMSPConfig\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0e\n\x06\x63onfig\x18\x02 \x01(\x0c\"\x83\x03\n\x0f\x46\x61\x62ricMSPConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\nroot_certs\x18\x02 \x03(\x0c\x12\x1a\n\x12intermediate_certs\x18\x03 \x03(\x0c\x12\x0e\n\x06\x61\x64mins\x18\x04 \x03(\x0c\x12\x17\n\x0frevocation_list\x18\x05 \x03(\x0c\x12\x32\n\x10signing_identity\x18\x06 \x01(\x0b\x32\x18.msp.SigningIdentityInfo\x12@\n\x1forganizational_unit_identifiers\x18\x07 \x03(\x0b\x32\x17.msp.FabricOUIdentifier\x12.\n\rcrypto_config\x18\x08 \x01(\x0b\x32\x17.msp.FabricCryptoConfig\x12\x16\n\x0etls_root_certs\x18\t \x03(\x0c\x12\x1e\n\x16tls_intermediate_certs\x18\n \x03(\x0c\x12+\n\x0f\x66\x61\x62ric_node_ous\x18\x0b \x01(\x0b\x32\x12.msp.FabricNodeOUs\"^\n\x12\x46\x61\x62ricCryptoConfig\x12\x1d\n\x15signature_hash_family\x18\x01 \x01(\t\x12)\n!identity_identifier_hash_function\x18\x02 \x01(\t\"~\n\x0fIdemixMSPConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03ipk\x18\x02 \x01(\x0c\x12*\n\x06signer\x18\x03 \x01(\x0b\x32\x1a.msp.IdemixMSPSignerConfig\x12\x15\n\rrevocation_pk\x18\x04 \x01(\x0c\x12\r\n\x05\x65poch\x18\x05 \x01(\x03\"\xa9\x01\n\x15IdemixMSPSignerConfig\x12\x0c\n\x04\x63red\x18\x01 \x01(\x0c\x12\n\n\x02sk\x18\x02 \x01(\x0c\x12&\n\x1eorganizational_unit_identifier\x18\x03 \x01(\t\x12\x0c\n\x04role\x18\x04 \x01(\x05\x12\x15\n\renrollment_id\x18\x05 \x01(\t\x12)\n!credential_revocation_information\x18\x06 \x01(\x0c\"R\n\x13SigningIdentityInfo\x12\x15\n\rpublic_signer\x18\x01 \x01(\x0c\x12$\n\x0eprivate_signer\x18\x02 \x01(\x0b\x32\x0c.msp.KeyInfo\"7\n\x07KeyInfo\x12\x16\n\x0ekey_identifier\x18\x01 \x01(\t\x12\x14\n\x0ckey_material\x18\x02 \x01(\x0c\"Q\n\x12\x46\x61\x62ricOUIdentifier\x12\x13\n\x0b\x63\x65rtificate\x18\x01 \x01(\x0c\x12&\n\x1eorganizational_unit_identifier\x18\x02 \x01(\t\"\xf9\x01\n\rFabricNodeOUs\x12\x0e\n\x06\x65nable\x18\x01 \x01(\x08\x12\x35\n\x14\x63lient_ou_identifier\x18\x02 \x01(\x0b\x32\x17.msp.FabricOUIdentifier\x12\x33\n\x12peer_ou_identifier\x18\x03 \x01(\x0b\x32\x17.msp.FabricOUIdentifier\x12\x34\n\x13\x61\x64min_ou_identifier\x18\x04 \x01(\x0b\x32\x17.msp.FabricOUIdentifier\x12\x36\n\x15orderer_ou_identifier\x18\x05 \x01(\x0b\x32\x17.msp.FabricOUIdentifierBb\n!org.hyperledger.fabric.protos.mspB\x10MspConfigPackageZ+github.com/hyperledger/fabric-protos-go/mspb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'msp.msp_config_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!org.hyperledger.fabric.protos.mspB\020MspConfigPackageZ+github.com/hyperledger/fabric-protos-go/msp'
  _MSPCONFIG._serialized_start=29
  _MSPCONFIG._serialized_end=70
  _FABRICMSPCONFIG._serialized_start=73
  _FABRICMSPCONFIG._serialized_end=460
  _FABRICCRYPTOCONFIG._serialized_start=462
  _FABRICCRYPTOCONFIG._serialized_end=556
  _IDEMIXMSPCONFIG._serialized_start=558
  _IDEMIXMSPCONFIG._serialized_end=684
  _IDEMIXMSPSIGNERCONFIG._serialized_start=687
  _IDEMIXMSPSIGNERCONFIG._serialized_end=856
  _SIGNINGIDENTITYINFO._serialized_start=858
  _SIGNINGIDENTITYINFO._serialized_end=940
  _KEYINFO._serialized_start=942
  _KEYINFO._serialized_end=997
  _FABRICOUIDENTIFIER._serialized_start=999
  _FABRICOUIDENTIFIER._serialized_end=1080
  _FABRICNODEOUS._serialized_start=1083
  _FABRICNODEOUS._serialized_end=1332
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from fabric_protos_python.orderer import cluster_pb2 as orderer_dot_cluster__pb2


class ClusterStub(object):
    """Cluster defines communication between cluster members.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Step = channel.stream_stream(
                '/orderer.Cluster/Step',
                request_serializer=orderer_dot_cluster__pb2.StepRequest.SerializeToString,
                response_deserializer=orderer_dot_cluster__pb2.StepResponse.FromString,
                )


class ClusterServicer(object):
    """Cluster defines communication between cluster members.
    """

    def Step(self, request_iterator, context):
        """Step passes an implementation-specific message to another cluster member.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ClusterServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Step': grpc.stream_stream_rpc_method_handler(
                    servicer.Step,
                    request_deserializer=orderer_dot_cluster__pb2.StepRequest.FromString,
                    response_serializer=orderer_dot_cluster__pb2.StepResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'orderer.Cluster', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Cluster(object):
    """Cluster defines communication between cluster members.
    """

    @staticmethod
    def Step(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/orderer.Cluster/Step',
            orderer_dot_cluster__pb2.StepRequest.SerializeToString,
            orderer_dot_cluster__pb2.StepResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from fabric_protos_python.peer import chaincode_shim_pb2 as peer_dot_chaincode__shim__pb2


class ChaincodeSupportStub(object):
    """Interface that provides support to chaincode execution. ChaincodeContext
    provides the context necessary for the server to respond appropriately.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Register = channel.stream_stream(
                '/protos.ChaincodeSupport/Register',
                request_serializer=peer_dot_chaincode__shim__pb2.ChaincodeMessage.SerializeToString,
                response_deserializer=peer_dot_chaincode__shim__pb2.ChaincodeMessage.FromString,
                )


class ChaincodeSupportServicer(object):
    """Interface that provides support to chaincode execution. ChaincodeContext
    provides the context necessary for the server to respond appropriately.
    """

    def Register(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ChaincodeSupportServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Register': grpc.stream_stream_rpc_method_handler(
                    servicer.Register,
                    request_deserializer=peer_dot_chaincode__shim__pb2.ChaincodeMessage.FromString,
                    response_serializer=peer_dot_chaincode__shim__pb2.ChaincodeMessage.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'protos.ChaincodeSupport', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ChaincodeSupport(object):
    """Interface that provides support to chaincode execution. ChaincodeContext
    provides the context necessary for the server to respond appropriately.
    """

    @staticmethod
    def Register(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/protos.ChaincodeSupport/Register',
            peer_dot_chaincode__shim__pb2.ChaincodeMessage.SerializeToString,
            peer_dot_chaincode__shim__pb2.ChaincodeMessage.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class ChaincodeStub(object):
    """Chaincode as a server - peer establishes a connection to the chaincode as a client
    Currently only supports a stream connection.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Connect = channel.stream_stream(
                '/protos.Chaincode/Connect',
                request_serializer=peer_dot_chaincode__shim__pb2.ChaincodeMessage.SerializeToString,
                response_deserializer=peer_dot_chaincode__shim__pb2.ChaincodeMessage.FromString,
                )


class ChaincodeServicer(object):
    """Chaincode as a server - peer establishes a connection to the chaincode as a client
    Currently only supports a stream connection.
    """

    def Connect(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ChaincodeServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Connect': grpc.stream_stream_rpc_method_handler(
                    servicer.Connect,
                    request_deserializer=peer_dot_chaincode__shim__pb2.ChaincodeMessage.FromString,
                    response_serializer=peer_dot_chaincode__shim__pb2.ChaincodeMessage.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'protos.Chaincode', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Chaincode(object):
    """Chaincode as a server - peer establishes a connection to the chaincode as a client
    Currently only supports a stream connection.
    """

    @staticmethod
    def Connect(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/protos.Chaincode/Connect',
            peer_dot_chaincode__shim__pb2.ChaincodeMessage.SerializeToString,
            peer_dot_chaincode__shim__pb2.ChaincodeMessage.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from fabric_protos_python.discovery import protocol_pb2 as discovery_dot_protocol__pb2


class DiscoveryStub(object):
    """Discovery defines a service that serves information about the fabric network
    like which peers, orderers, chaincodes, etc.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Discover = channel.unary_unary(
                '/discovery.Discovery/Discover',
                request_serializer=discovery_dot_protocol__pb2.SignedRequest.SerializeToString,
                response_deserializer=discovery_dot_protocol__pb2.Response.FromString,
                )


class DiscoveryServicer(object):
    """Discovery defines a service that serves information about the fabric network
    like which peers, orderers, chaincodes, etc.
    """

    def Discover(self, request, context):
        """Discover receives a signed request, and returns a response.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DiscoveryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Discover': grpc.unary_unary_rpc_method_handler(
                    servicer.Discover,
                    request_deserializer=discovery_dot_protocol__pb2.SignedRequest.FromString,
                    response_serializer=discovery_dot_protocol__pb2.Response.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'discovery.Discovery', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Discovery(object):
    """Discovery defines a service that serves information about the fabric network
    like which peers, orderers, chaincodes, etc.
    """

    @staticmethod
    def Discover(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/discovery.Discovery/Discover',
            discovery_dot_protocol__pb2.SignedRequest.SerializeToString,
            discovery_dot_protocol__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: msp/identities.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14msp/identities.proto\x12\x03msp\"5\n\x12SerializedIdentity\x12\r\n\x05mspid\x18\x01 \x01(\t\x12\x10\n\x08id_bytes\x18\x02 \x01(\x0c\"a\n\x18SerializedIdemixIdentity\x12\r\n\x05nym_x\x18\x01 \x01(\x0c\x12\r\n\x05nym_y\x18\x02 \x01(\x0c\x12\n\n\x02ou\x18\x03 \x01(\x0c\x12\x0c\n\x04role\x18\x04 \x01(\x0c\x12\r\n\x05proof\x18\x05 \x01(\x0c\x42P\n!org.hyperledger.fabric.protos.mspZ+github.com/hyperledger/fabric-protos-go/mspb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'msp.identities_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!org.hyperledger.fabric.protos.mspZ+github.com/hyperledger/fabric-protos-go/msp'
  _SERIALIZEDIDENTITY._serialized_start=29
  _SERIALIZEDIDENTITY._serialized_end=82
  _SERIALIZEDIDEMIXIDENTITY._serialized_start=84
  _SERIALIZEDIDEMIXIDENTITY._serialized_end=181
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: peer/policy.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fabric_protos_python.common import policies_pb2 as common_dot_policies__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11peer/policy.proto\x12\x06protos\x1a\x15\x63ommon/policies.proto\"\x83\x01\n\x11\x41pplicationPolicy\x12;\n\x10signature_policy\x18\x01 \x01(\x0b\x32\x1f.common.SignaturePolicyEnvelopeH\x00\x12)\n\x1f\x63hannel_config_policy_reference\x18\x02 \x01(\tH\x00\x42\x06\n\x04TypeBR\n\"org.hyperledger.fabric.protos.peerZ,github.com/hyperledger/fabric-protos-go/peerb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'peer.policy_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"org.hyperledger.fabric.protos.peerZ,github.com/hyperledger/fabric-protos-go/peer'
  _APPLICATIONPOLICY._serialized_start=53
  _APPLICATIONPOLICY._serialized_end=184
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: peer/events.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fabric_protos_python.common import common_pb2 as common_dot_common__pb2
from fabric_protos_python.ledger.rwset import rwset_pb2 as ledger_dot_rwset_dot_rwset__pb2
from fabric_protos_python.peer import chaincode_event_pb2 as peer_dot_chaincode__event__pb2
from fabric_protos_python.peer import transaction_pb2 as peer_dot_transaction__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11peer/events.proto\x12\x06protos\x1a\x13\x63ommon/common.proto\x1a\x18ledger/rwset/rwset.proto\x1a\x1apeer/chaincode_event.proto\x1a\x16peer/transaction.proto\"o\n\rFilteredBlock\x12\x12\n\nchannel_id\x18\x01 \x01(\t\x12\x0e\n\x06number\x18\x02 \x01(\x04\x12:\n\x15\x66iltered_transactions\x18\x04 \x03(\x0b\x32\x1b.protos.FilteredTransaction\"\xc6\x01\n\x13\x46ilteredTransaction\x12\x0c\n\x04txid\x18\x01 \x01(\t\x12 \n\x04type\x18\x02 \x01(\x0e\x32\x12.common.HeaderType\x12\x34\n\x12tx_validation_code\x18\x03 \x01(\x0e\x32\x18.protos.TxValidationCode\x12\x41\n\x13transaction_actions\x18\x04 \x01(\x0b\x32\".protos.FilteredTransactionActionsH\x00\x42\x06\n\x04\x44\x61ta\"X\n\x1a\x46ilteredTransactionActions\x12:\n\x11\x63haincode_actions\x18\x01 \x03(\x0b\x32\x1f.protos.FilteredChaincodeAction\"J\n\x17\x46ilteredChaincodeAction\x12/\n\x0f\x63haincode_event\x18\x01 \x01(\x0b\x32\x16.protos.ChaincodeEvent\"\xcf\x01\n\x13\x42lockAndPrivateData\x12\x1c\n\x05\x62lock\x18\x01 \x01(\x0b\x32\r.common.Block\x12I\n\x10private_data_map\x18\x02 \x03(\x0b\x32/.protos.BlockAndPrivateData.PrivateDataMapEntry\x1aO\n\x13PrivateDataMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\x04\x12\'\n\x05value\x18\x02 \x01(\x0b\x32\x18.rwset.TxPvtReadWriteSet:\x02\x38\x01\"\xcb\x01\n\x0f\x44\x65liverResponse\x12 \n\x06status\x18\x01 \x01(\x0e\x32\x0e.common.StatusH\x00\x12\x1e\n\x05\x62lock\x18\x02 \x01(\x0b\x32\r.common.BlockH\x00\x12/\n\x0e\x66iltered_block\x18\x03 \x01(\x0b\x32\x15.protos.FilteredBlockH\x00\x12=\n\x16\x62lock_and_private_data\x18\x04 \x01(\x0b\x32\x1b.protos.BlockAndPrivateDataH\x00\x42\x06\n\x04Type2\xd4\x01\n\x07\x44\x65liver\x12:\n\x07\x44\x65liver\x12\x10.common.Envelope\x1a\x17.protos.DeliverResponse\"\x00(\x01\x30\x01\x12\x42\n\x0f\x44\x65liverFiltered\x12\x10.common.Envelope\x1a\x17.protos.DeliverResponse\"\x00(\x01\x30\x01\x12I\n\x16\x44\x65liverWithPrivateData\x12\x10.common.Envelope\x1a\x17.protos.DeliverResponse\"\x00(\x01\x30\x01\x42\x61\n\"org.hyperledger.fabric.protos.peerB\rEventsPackageZ,github.com/hyperledger/fabric-protos-go/peerb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'peer.events_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"org.hyperledger.fabric.protos.peerB\rEventsPackageZ,github.com/hyperledger/fabric-protos-go/peer'
  _BLOCKANDPRIVATEDATA_PRIVATEDATAMAPENTRY._options = None
  _BLOCKANDPRIVATEDATA_PRIVATEDATAMAPENTRY._serialized_options = b'8\001'
  _FILTEREDBLOCK._serialized_start=128
  _FILTEREDBLOCK._serialized_end=239
  _FILTEREDTRANSACTION._serialized_start=242
  _FILTEREDTRANSACTION._serialized_end=440
  _FILTEREDTRANSACTIONACTIONS._serialized_start=442
  _FILTEREDTRANSACTIONACTIONS._serialized_end=530
  _FILTEREDCHAINCODEACTION._serialized_start=532
  _FILTEREDCHAINCODEACTION._serialized_end=606
  _BLOCKANDPRIVATEDATA._serialized_start=609
  _BLOCKANDPRIVATEDATA._serialized_end=816
  _BLOCKANDPRIVATEDATA_PRIVATEDATAMAPENTRY._serialized_start=737
  _BLOCKANDPRIVATEDATA_PRIVATEDATAMAPENTRY._serialized_end=816
  _DELIVERRESPONSE._serialized_start=819
  _DELIVERRESPONSE._serialized_end=1022
  _DELIVER._serialized_start=1025
  _DELIVER._serialized_end=1237
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common/common.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x63ommon/common.proto\x12\x06\x63ommon\x1a\x1fgoogle/protobuf/timestamp.proto\"\x1b\n\nLastConfig\x12\r\n\x05index\x18\x01 \x01(\x04\"H\n\x08Metadata\x12\r\n\x05value\x18\x01 \x01(\x0c\x12-\n\nsignatures\x18\x02 \x03(\x0b\x32\x19.common.MetadataSignature\"@\n\x11MetadataSignature\x12\x18\n\x10signature_header\x18\x01 \x01(\x0c\x12\x11\n\tsignature\x18\x02 \x01(\x0c\":\n\x06Header\x12\x16\n\x0e\x63hannel_header\x18\x01 \x01(\x0c\x12\x18\n\x10signature_header\x18\x02 \x01(\x0c\"\xb9\x01\n\rChannelHeader\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0f\n\x07version\x18\x02 \x01(\x05\x12-\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nchannel_id\x18\x04 \x01(\t\x12\r\n\x05tx_id\x18\x05 \x01(\t\x12\r\n\x05\x65poch\x18\x06 \x01(\x04\x12\x11\n\textension\x18\x07 \x01(\x0c\x12\x15\n\rtls_cert_hash\x18\x08 \x01(\x0c\"1\n\x0fSignatureHeader\x12\x0f\n\x07\x63reator\x18\x01 \x01(\x0c\x12\r\n\x05nonce\x18\x02 \x01(\x0c\"7\n\x07Payload\x12\x1e\n\x06header\x18\x01 \x01(\x0b\x32\x0e.common.Header\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\".\n\x08\x45nvelope\x12\x0f\n\x07payload\x18\x01 \x01(\x0c\x12\x11\n\tsignature\x18\x02 \x01(\x0c\"v\n\x05\x42lock\x12#\n\x06header\x18\x01 \x01(\x0b\x32\x13.common.BlockHeader\x12\x1f\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x11.common.BlockData\x12\'\n\x08metadata\x18\x03 \x01(\x0b\x32\x15.common.BlockMetadata\"G\n\x0b\x42lockHeader\x12\x0e\n\x06number\x18\x01 \x01(\x04\x12\x15\n\rprevious_hash\x18\x02 \x01(\x0c\x12\x11\n\tdata_hash\x18\x03 \x01(\x0c\"\x19\n\tBlockData\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\x0c\"!\n\rBlockMetadata\x12\x10\n\x08metadata\x18\x01 \x03(\x0c\"[\n\x14OrdererBlockMetadata\x12\'\n\x0blast_config\x18\x01 \x01(\x0b\x32\x12.common.LastConfig\x12\x1a\n\x12\x63onsenter_metadata\x18\x02 \x01(\x0c*\xc0\x01\n\x06Status\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0c\n\x07SUCCESS\x10\xc8\x01\x12\x10\n\x0b\x42\x41\x44_REQUEST\x10\x90\x03\x12\x0e\n\tFORBIDDEN\x10\x93\x03\x12\x0e\n\tNOT_FOUND\x10\x94\x03\x12\x1d\n\x18REQUEST_ENTITY_TOO_LARGE\x10\x9d\x03\x12\x1a\n\x15INTERNAL_SERVER_ERROR\x10\xf4\x03\x12\x14\n\x0fNOT_IMPLEMENTED\x10\xf5\x03\x12\x18\n\x13SERVICE_UNAVAILABLE\x10\xf7\x03*\xea\x01\n\nHeaderType\x12\x0b\n\x07MESSAGE\x10\x00\x12\n\n\x06\x43ONFIG\x10\x01\x12\x11\n\rCONFIG_UPDATE\x10\x02\x12\x18\n\x14\x45NDORSER_TRANSACTION\x10\x03\x12\x17\n\x13ORDERER_TRANSACTION\x10\x04\x12\x15\n\x11\x44\x45LIVER_SEEK_INFO\x10\x05\x12\x15\n\x11\x43HAINCODE_PACKAGE\x10\x06\"\x04\x08\x07\x10\x07\"\x04\x08\x08\x10\x08\"\x04\x08\t\x10\t*\x14PEER_RESOURCE_UPDATE*\x14PEER_ADMIN_OPERATION*\x11TOKEN_TRANSACTION*t\n\x12\x42lockMetadataIndex\x12\x0e\n\nSIGNATURES\x10\x00\x12\x13\n\x0bLAST_CONFIG\x10\x01\x1a\x02\x08\x01\x12\x17\n\x13TRANSACTIONS_FILTER\x10\x02\x12\x0f\n\x07ORDERER\x10\x03\x1a\x02\x08\x01\x12\x0f\n\x0b\x43OMMIT_HASH\x10\x04\x42V\n$org.hyperledger.fabric.protos.commonZ.github.com/hyperledger/fabric-protos-go/commonb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'common.common_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$org.hyperledger.fabric.protos.commonZ.github.com/hyperledger/fabric-protos-go/common'
  _BLOCKMETADATAINDEX.values_by_name["LAST_CONFIG"]._options = None
  _BLOCKMETADATAINDEX.values_by_name["LAST_CONFIG"]._serialized_options = b'\010\001'
  _BLOCKMETADATAINDEX.values_by_name["ORDERER"]._options = None
  _BLOCKMETADATAINDEX.values_by_name["ORDERER"]._serialized_options = b'\010\001'
  _STATUS._serialized_start=986
  _STATUS._serialized_end=1178
  _HEADERTYPE._serialized_start=1181
  _HEADERTYPE._serialized_end=1415
  _BLOCKMETADATAINDEX._serialized_start=1417
  _BLOCKMETADATAINDEX._serialized_end=1533
  _LASTCONFIG._serialized_start=64
  _LASTCONFIG._serialized_end=91
  _METADATA._serialized_start=93
  _METADATA._serialized_end=165
  _METADATASIGNATURE._serialized_start=167
  _METADATASIGNATURE._serialized_end=231
  _HEADER._serialized_start=233
  _HEADER._serialized_end=291
  _CHANNELHEADER._serialized_start=294
  _CHANNELHEADER._serialized_end=479
  _SIGNATUREHEADER._serialized_start=481
  _SIGNATUREHEADER._serialized_end=530
  _PAYLOAD._serialized_start=532
  _PAYLOAD._serialized_end=587
  _ENVELOPE._serialized_start=589
  _ENVELOPE._serialized_end=635
  _BLOCK._serialized_start=637
  _BLOCK._serialized_end=755
  _BLOCKHEADER._serialized_start=757
  _BLOCKHEADER._serialized_end=828
  _BLOCKDATA._serialized_start=830
  _BLOCKDATA._serialized_end=855
  _BLOCKMETADATA._serialized_start=857
  _BLOCKMETADATA._serialized_end=890
  _ORDERERBLOCKMETADATA._serialized_start=892
  _ORDERERBLOCKMETADATA._serialized_end=983
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common/configuration.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x63ommon/configuration.proto\x12\x06\x63ommon\" \n\x10HashingAlgorithm\x12\x0c\n\x04name\x18\x01 \x01(\t\"*\n\x19\x42lockDataHashingStructure\x12\r\n\x05width\x18\x01 \x01(\r\"%\n\x10OrdererAddresses\x12\x11\n\taddresses\x18\x01 \x03(\t\"\x1a\n\nConsortium\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x95\x01\n\x0c\x43\x61pabilities\x12<\n\x0c\x63\x61pabilities\x18\x01 \x03(\x0b\x32&.common.Capabilities.CapabilitiesEntry\x1aG\n\x11\x43\x61pabilitiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12!\n\x05value\x18\x02 \x01(\x0b\x32\x12.common.Capability:\x02\x38\x01\"\x0c\n\nCapabilityBV\n$org.hyperledger.fabric.protos.commonZ.github.com/hyperledger/fabric-protos-go/commonb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'common.configuration_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$org.hyperledger.fabric.protos.commonZ.github.com/hyperledger/fabric-protos-go/common'
  _CAPABILITIES_CAPABILITIESENTRY._options = None
  _CAPABILITIES_CAPABILITIESENTRY._serialized_options = b'8\001'
  _HASHINGALGORITHM._serialized_start=38
  _HASHINGALGORITHM._serialized_end=70
  _BLOCKDATAHASHINGSTRUCTURE._serialized_start=72
  _BLOCKDATAHASHINGSTRUCTURE._serialized_end=114
  _ORDERERADDRESSES._serialized_start=116
  _ORDERERADDRESSES._serialized_end=153
  _CONSORTIUM._serialized_start=155
  _CONSORTIUM._serialized_end=181
  _CAPABILITIES._serialized_start=184
  _CAPABILITIES._serialized_end=333
  _CAPABILITIES_CAPABILITIESENTRY._serialized_start=262
  _CAPABILITIES_CAPABILITIESENTRY._serialized_end=333
  _CAPABILITY._serialized_start=335
  _CAPABILITY._serialized_end=347
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common/configtx.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fabric_protos_python.common import common_pb2 as common_dot_common__pb2
from fabric_protos_python.common import policies_pb2 as common_dot_policies__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x63ommon/configtx.proto\x12\x06\x63ommon\x1a\x13\x63ommon/common.proto\x1a\x15\x63ommon/policies.proto\"W\n\x0e\x43onfigEnvelope\x12\x1e\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x0e.common.Config\x12%\n\x0blast_update\x18\x02 \x01(\x0b\x32\x10.common.Envelope\"R\n\x06\x43onfig\x12\x10\n\x08sequence\x18\x01 \x01(\x04\x12*\n\rchannel_group\x18\x02 \x01(\x0b\x32\x13.common.ConfigGroupJ\x04\x08\x03\x10\x04R\x04type\"Z\n\x14\x43onfigUpdateEnvelope\x12\x15\n\rconfig_update\x18\x01 \x01(\x0c\x12+\n\nsignatures\x18\x02 \x03(\x0b\x32\x17.common.ConfigSignature\"\xf1\x01\n\x0c\x43onfigUpdate\x12\x12\n\nchannel_id\x18\x01 \x01(\t\x12%\n\x08read_set\x18\x02 \x01(\x0b\x32\x13.common.ConfigGroup\x12&\n\twrite_set\x18\x03 \x01(\x0b\x32\x13.common.ConfigGroup\x12=\n\risolated_data\x18\x05 \x03(\x0b\x32&.common.ConfigUpdate.IsolatedDataEntry\x1a\x33\n\x11IsolatedDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01J\x04\x08\x04\x10\x05R\x04type\"\x98\x03\n\x0b\x43onfigGroup\x12\x0f\n\x07version\x18\x01 \x01(\x04\x12/\n\x06groups\x18\x02 \x03(\x0b\x32\x1f.common.ConfigGroup.GroupsEntry\x12/\n\x06values\x18\x03 \x03(\x0b\x32\x1f.common.ConfigGroup.ValuesEntry\x12\x33\n\x08policies\x18\x04 \x03(\x0b\x32!.common.ConfigGroup.PoliciesEntry\x12\x12\n\nmod_policy\x18\x05 \x01(\t\x1a\x42\n\x0bGroupsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\"\n\x05value\x18\x02 \x01(\x0b\x32\x13.common.ConfigGroup:\x02\x38\x01\x1a\x42\n\x0bValuesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\"\n\x05value\x18\x02 \x01(\x0b\x32\x13.common.ConfigValue:\x02\x38\x01\x1a\x45\n\rPoliciesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.common.ConfigPolicy:\x02\x38\x01\"A\n\x0b\x43onfigValue\x12\x0f\n\x07version\x18\x01 \x01(\x04\x12\r\n\x05value\x18\x02 \x01(\x0c\x12\x12\n\nmod_policy\x18\x03 \x01(\t\"S\n\x0c\x43onfigPolicy\x12\x0f\n\x07version\x18\x01 \x01(\x04\x12\x1e\n\x06policy\x18\x02 \x01(\x0b\x32\x0e.common.Policy\x12\x12\n\nmod_policy\x18\x03 \x01(\t\">\n\x0f\x43onfigSignature\x12\x18\n\x10signature_header\x18\x01 \x01(\x0c\x12\x11\n\tsignature\x18\x02 \x01(\x0c\x42V\n$org.hyperledger.fabric.protos.commonZ.github.com/hyperledger/fabric-protos-go/commonb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'common.configtx_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$org.hyperledger.fabric.protos.commonZ.github.com/hyperledger/fabric-protos-go/common'
  _CONFIGUPDATE_ISOLATEDDATAENTRY._options = None
  _CONFIGUPDATE_ISOLATEDDATAENTRY._serialized_options = b'8\001'
  _CONFIGGROUP_GROUPSENTRY._options = None
  _CONFIGGROUP_GROUPSENTRY._serialized_options = b'8\001'
  _CONFIGGROUP_VALUESENTRY._options = None
  _CONFIGGROUP_VALUESENTRY._serialized_options = b'8\001'
  _CONFIGGROUP_POLICIESENTRY._options = None
  _CONFIGGROUP_POLICIESENTRY._serialized_options = b'8\001'
  _CONFIGENVELOPE._serialized_start=77
  _CONFIGENVELOPE._serialized_end=164
  _CONFIG._serialized_start=166
  _CONFIG._serialized_end=248
  _CONFIGUPDATEENVELOPE._serialized_start=250
  _CONFIGUPDATEENVELOPE._serialized_end=340
  _CONFIGUPDATE._serialized_start=343
  _CONFIGUPDATE._serialized_end=584
  _CONFIGUPDATE_ISOLATEDDATAENTRY._serialized_start=521
  _CONFIGUPDATE_ISOLATEDDATAENTRY._serialized_end=572
  _CONFIGGROUP._serialized_start=587
  _CONFIGGROUP._serialized_end=995
  _CONFIGGROUP_GROUPSENTRY._serialized_start=790
  _CONFIGGROUP_GROUPSENTRY._serialized_end=856
  _CONFIGGROUP_VALUESENTRY._serialized_start=858
  _CONFIGGROUP_VALUESENTRY._serialized_end=924
  _CONFIGGROUP_POLICIESENTRY._serialized_start=926
  _CONFIGGROUP_POLICIESENTRY._serialized_end=995
  _CONFIGVALUE._serialized_start=997
  _CONFIGVALUE._serialized_end=1062
  _CONFIGPOLICY._serialized_start=1064
  _CONFIGPOLICY._serialized_end=1147
  _CONFIGSIGNATURE._serialized_start=1149
  _CONFIGSIGNATURE._serialized_end=1211
# @@protoc_insertion_point(module_scope)
